# This file aggregates the code used in "Statistics and Data Visualization Using R". 
# Since much of the code in the book becomes quite lengthy, we thought it might be helpful
# to include an R-Script file where students and instructors could easily cut and paste
# the commands.  I would like to thank Hannah Paul (Truman School of Government and Public
# Affairs, University of Missouri) for doing 99% of the work in putting this R-script
# together.  I would also like to thank Philip Hanser (Department of Economics, Northeastern
# University) for the encouragement to make this file publicly available.

# There might be slight deviations between what the code produces and what is seen in the 
# book because of the process involved in translating markdown files into the word 
# files used in publication.

# We'll also use this space to update code and announce any bugs we fix along the way.

# Bug Fixes 12/18/21

  # Code for defining variable 'nes$dpolice.new' was omitted from code chunk 10-1 but
  # is now included right after code chunk 10-1. We also included the variable in 
  # the latest version of the data.

  # The definition 'mean <- base::mean' is added in code chunk 3-2a to make executing
  # the stat_summary() command that follows functional.

  # Code chunk 7-8 was changed to count(nes$pid7) from count(nes, pid7).



  
# Chapter 1: Getting Started 

plot(states$medinc, states$stuspend,
     main = "Figure 1-1: Spending is Higher in Wealthier States",
     col = '#0000ff', pch = 20, font.main = 1)

hist(states$hsdiploma)
myobject <- hist(states$hsdiploma)
newobject <- c(1,1,1,1,3,4,5,5,5,5,6,6)
hist(newobject)

# Figure 1-7
hist(states$hsdiploma, main = "Figure 1-7: This Is My First Plot!",
     font.main = 1, col = "#0000ff")

# Figure 1-8
plot(states$hsdiploma, states$murderrate,
     main = "Figure 1-8: Education Reduces Violence \n",
     font.main = 1, col = "#0000ff", pch = 19)

# Figure 1-9
myobject <- c(1,1,1,1,3,4,5,5,5,5,6,6)
hist(myobject, main = "Figure 1-9: Object that You Defined",
     font.main = 1, col = "#00ff00")

# Figure 1-10
myobject <- c(1,2,3,3,3,4,4,4,5,5,6)
hist(myobject, main = "Figure 1-10: Object that You Defined",
     font.main = 1, col = "#0000ff")

# Chapter 2: An Introduction to Data Analysis

# Figure 2-1
ggplot(world, aes(ethfrac, log(gdppc), label = iso3c)) +
  geom_point(color="#0000ff") +
  geom_smooth(method="lm", se=FALSE, color="#00ff00") +
  ggtitle("Figure 2-1: ELF Lowers Income") +
  ylab("GDP per Capita (logged)") +
  xlab("Ethnolinguistic Fractionalization (ELF)") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
  axis.title = element_text(size = 8, face = "bold")) +
  geom_text_repel(size = 2.8, aes(label=ifelse(iso3c=="MDG" | iso3c=="LUX",
  as.character(iso3c),''),
  hjust = 0, vjust=-1), show.legend=FALSE)

# Figure 2-2
ggplot(world, aes(ethfrac, log(gdppc))) +
 geom_point(color=ifelse(world$aclpregion=="Industrial Countries", 
                         "#0000bf", "#bf0000")) +
 geom_smooth(method="lm", col="grey", se=FALSE,
 linetype = "dashed") +
 ggtitle("Figure 2-2: Industrialized Countries Are Clustered") +
 ylab("GDP per Capita (logged)") +
 xlab("Ethnolinguistic Fractionalization") +
 theme_minimal() +
 theme(plot.title = element_text(size = 8, face = "bold"),
 axis.title = element_text(size = 8, face = "bold")) +
 geom_smooth(data=subset(world, aclpregion != "Industrial Countries"),
 color="#bf0000", se=FALSE, method = "lm") +
 annotate("text", x = .15, y = 11.5,
 label = "Industrial Countries", col="#0000bf")

# Figure 2-3
ggplot(world, aes(ethfrac, log(gdppc))) +
  geom_point(color=ifelse(world$aclpregion=="Industrial Countries",
  "#0000bf", "#bf0000")) +
  geom_smooth(method="lm", col="grey", se=FALSE,
  linetype = "dashed") +
  ggtitle("Figure 2-3: The Relationship Could Be Nonlinear") +
  ylab("GDP per Capita (logged)") +
  xlab("Ethnolinguistic Fractionalization") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
  axis.title = element_text(size = 8, face = "bold")) +
  geom_smooth(data=subset(world,
  aclpregion != "Industrial Countries"),
  color="black", se=FALSE) +
  annotate("text", x = .15, y = 11.5,
  label = "Industrial Countries", col="blue")

# Figure 2-4
ggplot(world, aes(ethfrac, log(gdppc))) +
  geom_point(color=ifelse(world$iso3c=="COM" |
  world$iso3c=="HTI" |
  world$iso3c=="KIR" |
  world$iso3c=="SLB", "#0000bf", "grey")) +
  geom_smooth(method="lm", col="grey", se=FALSE,
  linetype = "dashed") +
  ggtitle("Figure 2-4: Small Countries Have Low GDP per Capita") +
  ylab("GDP per Capita (logged)") +
  xlab("Ethnolinguistic Fractionalization") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
  axis.title = element_text(size = 8, face = "bold")) +
  geom_smooth(data=subset(world,
  aclpregion != "Industrial Countries"),
  color="black", se=FALSE) +
  geom_text_repel(size = 2.8, aes(label=ifelse(iso3c=="COM" |
  iso3c=="HTI" |
  iso3c=="KIR" |
  iso3c=="SLB",
  as.character(iso3c),'')))

# Figure 2-5
ggplot(world, aes(womyear, log(gdppc))) +
  geom_point(col="#0000bf") +
  geom_smooth(method="lm", se=FALSE, color="#00ff00") +
  ggtitle("Figure 2-5: The Later the Suffrage, the Poorer the Country") +
  ylab("GDP per Capita (logged)") +
  xlab("Year Women Gained Suffrage") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
  axis.title = element_text(size = 8, face = "bold"))

# Figure 2-6
ggplot(world, aes(womyear, log(gdppc))) +
  geom_point(color=ifelse(world$aclpregion==
  "Industrial Countries", "#0000bf",
  ifelse(world$aclpregion==
  "Sub-Saharan Africa", "#bf0000", "grey"))) +
  annotate("text", x = 1905, y = 11.75,
  label = "Industrial Countries",
  col="#0000bf") +
  annotate("text", x = 1975, y = 6.2,
  label = "Sub-Saharan Africa", col="#bf0000") +
  geom_smooth(method="lm", se=FALSE, col="#00ff00") +
  ggtitle("Figure 2-6: The Industrial Countries and Sub-Saharan Africa Form Clusters") +
  ylab("GDP per Capita (logged)") +
  xlab("Year Women Gained Suffrage") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
  axis.title = element_text(size = 8, face = "bold"))

# Figure 2-7
ggplot(world, aes(womyear, log(gdppc))) +
  geom_point(color=ifelse(world$womyear < 1935, "#bf0000",
  ifelse(world$womyear > 1944,
  "#0000bf", "grey"))) +
  geom_smooth(method="lm", se=FALSE, col="#00ff00") +
  geom_vline(xintercept=1934, col="grey", linetype = "dashed") +
  geom_vline(xintercept=1944, col="grey", linetype = "dashed") +
  ggtitle("Figure 2-7: Gap During World War II") +
  ylab("GDP per Capita (logged)") +
  xlab("Year Women Gained Suffrage") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
  axis.title = element_text(size = 8, face = "bold"))

# Figure 2-8
ggplot(world, aes(womyear, log(gdppc))) +
  geom_point(color="#0000bf") +
  geom_smooth(method="lm", se=FALSE, color="#00ff00") +
  ggtitle("Figure 2-8: Large Variation in GDP per Capita") +
  ylab("GDP per Capita (logged)") +
  xlab("Year Women Gained Suffrage") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
  axis.title = element_text(size = 8, face = "bold")) +
  geom_text_repel(size = 2.8,
  aes(label=ifelse(iso3c=="ETH" |
  iso3c=="BDI" |
  iso3c=="SLE" |
  iso3c=="HUN" |
  iso3c=="CYP" |
  iso3c=="LBY",
  as.character(iso3c),''),
  hjust = 0, vjust=-1), show.legend=FALSE)

# Figure 2-9
world$SSA <- ifelse(world$region=="Sub-Saharan Africa", 1, 0)
world$SSA <- as.factor(world$SSA)

ggplot(world, aes(womyear, log(gdppc), col=SSA)) +
  geom_point() +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
  axis.title = element_text(size = 8, face = "bold")) +
  geom_smooth(method="lm", se=FALSE) +
  ggtitle("Figure 2-9: No Relationship in Sub-Saharan Africa") +
  ylab("GDP per Capita (logged)") +
  xlab("Year Women Gained Suffrage") +
  scale_color_manual(values=c("grey", "#0000bf")) +
  theme(legend.position = "none") +
  annotate("text", x = 1928, y = 6.8,
  label = "Sub-Saharan Africa", col="#0000bf")

# Figure 2-10
ggplot(world, aes(pwthc, log(gdppc))) +
  geom_point(col="#0000bf") +
  geom_smooth(method="lm", se=FALSE, col="#00ff00") +
  ggtitle("Figure 2-10: Strong Relationship Between GDP and Education") +
  ylab("GDP per Capita (logged)") +
  xlab("Barro and Lee’s Human Capital Index") +
  geom_text_repel(size = 2.8,
  aes(label=ifelse(iso3c=="QAT" |
  iso3c=="KWT" |
  iso3c=="ZWE",
  as.character(iso3c),''),
  hjust = 0, vjust=-1),
  show.legend=FALSE) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
  axis.title = element_text(size = 8, face = "bold"))

# Figure 2-11
ggplot(world, aes(log(durable + 1), log(gdppc))) +
  geom_point(col="#0000bf") +
  theme_minimal() +
  geom_smooth(se=FALSE, col="#00ff00", method="lm") +
  ggtitle("Figure 2-11: Political Stability Increases Wealth") +
  ylab("GDP per Capita (logged)") +
  xlab("Durable (logged)") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
  axis.title = element_text(size = 8, face = "bold"))

# Figure 2-12
ggplot(world, aes(log(durable + 1), log(gdppc))) +
  geom_point(col="grey") +
  geom_smooth(se=FALSE, col="#00ff00") +
  geom_smooth(method="lm", se=FALSE,
  linetype = "dashed", col = "grey") +
  ggtitle("Figure 2-12: The Nonlinear Relationship Between GDP per Capita and Political Stability") +
  ylab("GDP per Capita (logged)") +
  xlab("Durable (logged)") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
  axis.title = element_text(size = 8, face = "bold"))

# Table 2-1
mod1 <- lm(log(gdppc)~womyear, data=world)
stargazer(mod1, header=FALSE,
          title = "Table 2-1: Estimates for a Bivariate Model",
          type = "html", out = "table3.htm")

# Table 2-2

mod2 <- lm(log(gdppc)~womyear + ethfrac + durable + pwthc,
           data=world)
stargazer(mod2, header=FALSE,
          title = "Table 2-2: Estimates Are Unstable",
          type = "html", out = "table4.htm")

# Figure 2-13
visreg(mod2, "womyear", ylab="Predicted Values GDP (logged)",
       xlab="Year Women Gained Suffrage",
       main="Figure 2-13: Women’s Suffrage Has No Effect",
       band=FALSE)

# Code Chunk 2-16 (no table or graph)

mod2 <- lm(log(gdppc)~womyear + ethfrac + durable + pwthc, na.action = na.exclude,
           data=world)

world$res <- resid(mod2)
world$pred <- predict(mod2)

# Figure 2-14
ggplot(world, aes(pred, res)) +
  geom_point(col="#bf0000") +
  geom_text_repel(size = 2.8,
  aes(label=ifelse(iso3c=="SGP" |
  iso3c=="TJK" |
  iso3c=="ZWE" |
  iso3c=="USA" |
  iso3c=="LUX",
  as.character(iso3c),''),
  hjust = 0, vjust=-1), show.legend=FALSE) +
  geom_hline(yintercept = 0, linetype = 2) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
  axis.title = element_text(size = 8, face = "bold")) +
  xlab("Predicted or 'Fitted' Values") +
  ylab("Residuals") +
  ggtitle("Figure 2-14: Some Possible Outliers")


# Chapter 3: Describing Data`                                                                         

# Code Chunk 1a
stdat <- head(dplyr::select(states, state, region, trumpwin, percwom, inc))

# Table 3-1

knitr::kable(stdat, format = "pandoc", caption = "Table 3-1: First Six Lines of States Data")

wdat <- head(dplyr::select(world, country, gdppc, turnout, womyear))
kable(wdat, format = "pandoc")

# Code Chunk 3-2a

mean <- base::mean

world$g <- factor(world$regime,
                  levels = c("Royal Dictatorship",
                              "Military Dictatorship",
                              "Civilian Dictatorship",
                              "Mixed Democracy",
                              "Presidential Democracy",
                              "Parliamentary Democracy"))
# Code Chunk 3-2b
fig1 <- ggplot(world, aes(x=regime, y=(fdi))) +
  stat_summary(fun.y=mean, geom="bar", fill="#0000ff", aes(group=1)) +
  ylab("Not Ordered") +
  xlab("") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
        coord_flip(ylim=c(0,10))

fig2 <- ggplot(world, aes(x=g, y=(fdi))) +
  stat_summary(fun.y=mean, geom="bar", fill="#0000ff", aes(group=1)) +
  ylab("Ordered") +
  xlab("") +
  theme_minimal() +
  coord_flip(ylim=c(0,10)) +
  theme(plot.title = element_text(size = 8, face = "bold"),
  axis.title = element_text(size = 8, face = "bold"))

# Figure 3-2

grid.arrange(fig1, fig2, ncol=2, 
  top = textGrob("Figure 3-2: Unordered and Ordered 
                    View of Regime Type and FDI",gp=gpar(fontsize=10, fontface = "bold")))

# Code Chunk 3-3a
levels(nes$marstat)[levels(nes$marstat)=="Domestic Partnership"] <- "Dom. Part."

# Code Chunk 3-3b
nes$g <- factor(nes$marstat,levels(nes$marstat)[c(5, 1, 6, 2, 3, 4)])

# Code Chunk 3-3c
fig1 <- ggplot(nes, aes(x=marstat, y=ftgay)) +
  stat_summary(fun.y=mean, geom="bar", fill="#0000ff",
               aes(group=1)) +
  ylab("Not Ordered") +
  xlab("") +
  theme_minimal() +
  coord_flip(ylim=c(45,70)) +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold"))


fig2 <- ggplot(nes, aes(x=g, y=ftgay)) +
  stat_summary(fun.y=mean, geom="bar", fill="#0000ff",
               aes(group=1)) +
  ylab("Ordered") +
  xlab("") +
  theme_minimal() +
  coord_flip(ylim=c(45,70)) +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold"))

# Figure 3-3
grid.arrange(fig1, fig2, ncol=2, 
             top = textGrob("Figure 3-3: Unordered and Ordered View of 
                            Marital Status and Feeling Thermometer Toward Gays",
                            gp=gpar(fontsize=10,fontface = "bold")))

#Code Chunk 3-4a
myData <- data.frame(normal=rnorm(1000000, m=0, sd=1), skewed=rexp(1000000, rate=1))
data <- melt(myData, id.vars = NULL)

# Figure 3-4
ggplot(data, aes(x=value)) +
  geom_density(aes(group=variable, col=variable)) +
  theme_minimal() +
  scale_colour_manual(values =
  c("normal" = "#0000ff", "skewed" = "#bf0000")) +
  labs(color='Type of Distribution') +
  theme(legend.position = c(.7, .5)) +
  ggtitle("Figure 3-4: Normal and Exponential Distributions") +
  theme(plot.title = element_text(size = 8, face = "bold"),
  axis.title = element_text(size = 8, face = "bold"))

# Figure 3-5
ggplot(world,aes(x = turnout)) +
  geom_histogram(aes(y = ..ncount..), fill = "#0000ff") +
  geom_density(aes(y = ..scaled..)) +
  theme_minimal() +
  ylab("Scaled Density and Observation Count") +
  xlab("Voter Turnout") +
  ggtitle("Figure 3-5: Voter Turnout Is Normally Distributed") +
  theme(plot.title = element_text(size = 8, face = "bold"),
  axis.title = element_text(size = 8, face = "bold"))

# Figure 3-6
ggplot(world, aes(x = inf)) +
  geom_histogram(aes(y = ..ncount..), fill = "#0000ff") +
  geom_density(aes(y = ..scaled..)) +
  theme_minimal() +
  ylab("Scaled Density and Observation Count") +
  xlab("Infant Mortality Rate") +
  ggtitle("Figure 3-6: Infant Mortality Is Not Normally Distributed") +
                   theme(plot.title = element_text(size = 8, face = "bold"),
                         axis.title = element_text(size = 8, face = "bold"))

# Figure 3-7
ggplot(states, aes(x = hsdiploma)) +
  geom_histogram(aes(y = ..ncount..), fill = "#0000ff") +
  geom_density(aes(y = ..scaled..)) +
  theme_minimal() +
  ylab("Scaled Density and Observation Count") +
  xlab("Percentage of Population With High School Diploma") +
  ggtitle("Figure 3-7: Not Much Separation Between States") +
  theme(plot.title = element_text(size = 8, face = "bold"),
  axis.title = element_text(size = 8, face = "bold"))

# Code Chunk 3-8a
avgaytherm <- as_tibble(subset(nes, pid7!="NA" & pid7!="Not sure"))

# Code Chunk 3-8b
dt <- avgaytherm %>%
  group_by(pid7) %>%
  summarise(ftpolice.mean = mean(ftpolice)) %>%
  mutate_if(is.numeric, format, digits=4)

# Table 3-2
kable(dt, format = "pandoc",
      caption = "Table 3-2: Democrats Show Less Support for Police")

# Code Chunk 3-9a
df <- world %>%
  dplyr::select(nourish, gtbeduc, polity2, gdppc)

# Code Chunk 3-9b

dft <- basicStats(df)[c("nobs", "NAs"),]

# Table 3-3
kable(dft, format = "pandoc", caption =
        "Table 3-3: Too Many Missing Cases (NAs)")

# Figure 3-8
ggplot(states, aes(inc, infant, col=region)) +
  geom_point() +
  theme_minimal() +
  ggtitle("Figure 3-8: Infant Mortality and Income in the United States") +
  ylab("Deaths per 1,000 Live Births") +
  xlab("Income per Capita") +
  scale_colour_manual(values = c("South" = "#0000ff",
                                  "West" = "#bf0000", 
                                  "Midwest" = "#00ffff",
                                  "Northeast" = "#04183d")) +
                                   labs(color="") +
  theme(legend.position = c(.75,.75)) +
  theme(plot.title = element_text(size = 8, face = "bold"),
  axis.title = element_text(size = 8, face = "bold"))

# Code Chunk 3-11a
ed <- states %>%
  dplyr::select(state, hsdiploma) %>%
  arrange(desc(hsdiploma)) %>%
  slice(1:15)

# Table 3-4
kable(ed, format = "pandoc", caption = "Table 3-4: Top 15 States")


# Chapter 4: Central Tendency and Disperson

# Figure 4-1
ggplot(nes, aes(x=pid7)) +
  geom_bar(fill="#0000ff") +
  theme_minimal() +
  ggtitle("Figure 4-1: Strong Democrats Outnumber Strong Republicans") +
  xlab("Party Identification") +
  ylab("Number of Respondents") +
  coord_flip() +
  theme(plot.title = element_text(size = 8, face = "bold"),
  axis.title = element_text(size = 8, face = "bold"))

# Code Chunk 4-2a
mean(world$homicide, na.rm = TRUE)

## [1] 8.459007


# Figure 4-2
ggplot(world, aes(homicide)) +
  geom_histogram(bins=20, fill = "#0000ff") +
  labs(title="Figure 4-2: Average Homicide Rate for the World") +
  xlab("Number of Homicides per 100,000 Population") +
  ylab("Count") +
  geom_vline(xintercept=8.45, col="#bf0000") +
  annotate("text", x = 12, y = -7, label = "8.45", col="#bf0000", size = 3) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
  axis.title = element_text(size = 8, face = "bold"))

# Code Chunk 4-3a
median(world$homicide, na.rm = TRUE)
## [1] 3.3

# Figure 4-3
ggplot(world, aes(homicide)) +
  geom_histogram(bins=20, fill = "#0000ff") +
  ggtitle("Figure 4-3: Median Homicide Rate for the World") +
  xlab("Number of Homicides per 100,000 Population") +
  ylab("Count") + 
  geom_vline(xintercept=3.3, col="#bf0000") +
  annotate("text", x = 7, y = -7, label = "3.3", col="#bf0000", size = 3) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
  axis.title = element_text(size = 8, face = "bold"))

# Figure 4-4
ggplot(world, aes(durable)) +
  geom_histogram(bins=20, fill = "#0000ff", alpha=.5) +
  ggtitle("Figure 4-4: The Mean and Median Differ") +
  xlab("Number of Years Since Significant Constitutional Change") +
  ylab("Count") +
  geom_vline(xintercept=27.2, col="#bf0000") +
  geom_vline(xintercept=17, col="#0000ff") +
  annotate("text", x = 100, y = 30,
  label = "Mean = 27.2", col="#bf0000", size = 3) +
  annotate("text", x = 100, y = 35,
  label = "Median = 17", col="#0000ff", size = 3) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
  axis.title = element_text(size = 8, face = "bold"))

# Code Chunk 4-5a
world$newdurable <- world$durable
world$newdurable <- replace(world$newdurable,
                            world$newdurable==199, 1999)

mean(world$newdurable, na.rm=TRUE)
## [1] 38.61392

# Figure 4-5
ggplot(world, aes(durable)) +
  geom_histogram(bins=20, fill = "#0000ff", alpha=.5) +
  labs(title="Figure 4-5: Extreme Value Moves the Mean") +
  xlab("Number of Years Since Significant Constitutional Change") +
  ylab("Count")+
  geom_vline(xintercept=27.2, col="#bf0000") +
  geom_vline(xintercept=17, col="#0000ff") +
  geom_vline(xintercept=38.6, col="#00ff00",
  linetype = "dashed") +
  annotate("text", x = 125, y = 30,
  label = "Mean With Typo Moves From 27.2 to 38.6",
  col = "#00ff00", size = 3) +
  annotate("text", x = 125, y = 25,
  label = "Median Stays the Same = 17", col = "#0000ff", size = 3) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
  axis.title = element_text(size = 8, face = "bold"))


# Code Chunk 4-6
summary(states$infant)
## Min. 1st Qu. Median Mean 3rd Qu. Max.
## 4.520 5.938 6.785 6.981 7.878 11.470

# Code Chunk 4-7
summary(states$infant)
## Min. 1st Qu. Median Mean 3rd Qu. Max.
## 4.520 5.938 6.785 6.981 7.878 11.470

# Code Chunk
summary(world$durable)
## Min. 1st Qu. Median Mean 3rd Qu. Max. NA’s
## 0.00 8.00 17.00 27.22 38.50 199.00 24

# Code Chunk 4-9
summary(world$newdurable)
## Min. 1st Qu. Median Mean 3rd Qu. Max. NA’s
## 0.00 8.00 17.00 38.61 38.50 1999.00 24

# Code Chunk 4-10
sd(states$femleg, na.rm = TRUE)
## [1] 7.197513
sd(states$infant, na.rm = TRUE)
## [1] 1.435324

# Code Chunk 4-11
cash <- c(10, 20, 40, 15, 10)
mean(cash)
## [1] 19

#Code Chunk 4-12
sd(cash)
## [1] 12.4499

# Code Chunk 4-13a
h <- data.frame(1:500)
set.seed(42)
h$p1 <- rnorm(500,0,1)
h$p2 <- rnorm(500,0,2)
h$p3 <- rnorm(500,0,3)

# Code Chunk 4-13b

data_long <- gather(h, condition, measurement,
                    p1:p3, factor_key=TRUE)

data_long$condition <- factor(data_long$condition,
                              levels = c("p1","p2","p3"),
                              labels = c("Std=1", "Std=2",
                                          "Std=3"))

# Figure 4-6
ggplot(data_long, aes(measurement)) +
  geom_histogram(aes(measurement), fill = "#0000ff") +
  facet_grid(.~condition) +
  labs(title="Figure 4-6: Standard Deviation of Random Variable Doubled and Tripled") +
  xlab("") +
  ylab("Count") + 
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
  axis.title = element_text(size = 8, face = "bold"))


# Code Chunk 4-14
sd(world$durable, na.rm = TRUE)
## [1] 31.1848

summary(world$durable)
## Min. 1st Qu. Median Mean 3rd Qu. Max. NA’s
## 0.00 8.00 17.00 27.22 38.50 199.00 24

sd(world$newdurable, na.rm = TRUE)
## [1] 159.4293

summary(world$newdurable)
## Min. 1st Qu. Median Mean 3rd Qu. Max. NA’s
## 0.00 8.00 17.00 38.61 38.50 1999.00 24

# Answers

# 7 
ggplot(world, aes(womleg)) +
  geom_histogram(bins=20, fill = "#0000ff", alpha=.5) +
  labs(title="Histogram of world$womleg") +
  xlab("Percentage of Seats Occupied by Women") +
  ylab("Count")+
  geom_vline(xintercept=(17.5 + 11), col="#bf0000") +
  geom_vline(xintercept=17.5, col="#0000ff") +
  geom_vline(xintercept=(17.5 - 11), col="#00ff00") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
  axis.title = element_text(size = 8, face = "bold"))

# 8
ggplot(world, aes(womleg)) +
  geom_histogram(bins=20, fill = "#0000ff", alpha=.5) +
  labs(title="Interquartile Range of world$womleg") +
  xlab("Percentage of Seats Occupied by Women") +
  ylab("Count") + 
  geom_vline(xintercept=9.8, col="#bf0000") +
  geom_vline(xintercept=23.4, col="#0000ff") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold"))

# 10 
ggplot(world, aes(inf)) +
  geom_histogram(bins=20, fill = "#0000ff", alpha=.5) +
  labs(title="Histogram of Infant Morality") +
  xlab("Deaths per 1,000 Live Births") +
  ylab("Count") +
  geom_vline(xintercept=7.7, col="#bf0000") +
  geom_vline(xintercept=28.2, col="#0000ff") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold"))

# Chapter 5: Univariate and Bivariate Descriptions of Data

# Table 5-1
freq(nes$pid3, plot = options(descr.plot = FALSE))

# Table 5-2
freq(nes$employ, plot = options(descr.plot = FALSE))

# Figure 5-1
ggplot(nes, aes(employ)) +
  geom_bar(fill = "#0000bf") +
  theme_minimal() +
  ggtitle("Figure 5-1: Barplot of Employment Variable") +
  xlab("") +
  ylab("Number of Respondents") +
  coord_flip() +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold"))

# Figure 5-2
ggplot(world, aes(x="", turnout)) +
  geom_boxplot(col="#0000bf") +
  theme_minimal() +
  ggtitle("Figure 5-2: Boxplot of Turnout") +
  ylab("Percent Voting in Last Election") +
  xlab("") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold"))

# Figure 5-3
ggplot(world, aes(x="", gdppc)) +
  geom_boxplot(color="#0000ff") +
  theme_minimal() +
  ggtitle("Figure 5-3: Skewed Distribution") +
  ylab("GDP in Dollars per Capita") +
  xlab("") +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold"))

# Figure 5-4
ggplot(states, aes(x=factor(0), y=murderrate)) +
  geom_boxplot(outlier.colour=NA, fill=NA, colour="grey20") +
  geom_point(fill = "#bf0000", size=2,
             shape=21, colour="grey",
             position=position_jitter(seed = 1)) +
  geom_text_repel(aes(label = st), col = "grey",
                  position = position_jitter(seed = 1),
                  hjust=1, vjust=2) +
  theme_minimal() +
  ggtitle("Figure 5-4: Fancy Boxplot") +
  ylab("Homicide Rate:\n Murders per 100,000 Population") +
  xlab("") +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold")) +
  theme(axis.text.x=element_blank())

# Figure 5-5
ggplot(world, aes(durable)) +
  geom_histogram(bins=10, fill = "#0000bf") +
  ggtitle("Figure 5-5: Histogram of the durable Variable") +
  xlab("Years Since Last Significant Regime Change") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold"))

# Figure 5-6
ggplot(world, aes(durable)) +
  geom_histogram(bins=3, fill = "#0000bf") +
  labs(title = paste("Figure 5-6: Not Enough Bins")) +
  xlab("Years Since Last Significant Regime Change") +
  ylab("Count")+
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold"))

# Figure 5-7
p1 <- ggplot(states, aes(freedom)) +
  geom_histogram(bins=10, fill = "#0000bf") +
  ggtitle("Freedom") +
  xlab("Personal Freedom Score") +
  ylab("Count") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold"))

p2 <- ggplot(states, aes(turnout)) +
  geom_histogram(bins=10, fill = "#0000bf") +
  ggtitle("Turnout") +
  xlab("Turnout in 2012 Election") +
  ylab("Count") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold"))
  
p3 <- ggplot(states, aes(stuspend)) +
  geom_histogram(bins=10, fill = "#0000bf") +
  ggtitle("Stuspend") +
  xlab("Dollars Spent per Student") +
  ylab("Count") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold"))

grid.arrange(p1, p2, p3, nrow=1, ncol=3,
             top = textGrob("Figure 5-7: Examples of Skewness",
                             gp=gpar(fontsize=10,fontface = "bold")))

# Figure 5-8
options(scipen = 999)

plot1 <- ggplot(world, aes(gdppc)) +
  geom_histogram(bins=20, fill = "#0000bf") +
  ggtitle("Skewed") +
  xlab("GDP per Capita") +
  ylab("Count") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold"))

plot2 <- ggplot(world, aes(log(gdppc))) +
  geom_histogram(bins=20, fill = "#0000bf") +
  ggtitle("Normal") +
  xlab("GDP per Capita (logged)") +
  ylab("Count") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold"))
                                  
grid.arrange(plot1, plot2, nrow=1, ncol=2,
  top = textGrob("Figure 5-8: Skewed and Normal Distribution",
  gp=gpar(fontsize=10,fontface = "bold")))

# Figure 5-9
stem(states$percwom, scale = 2)

# Figure 5-10
stem(states$inc, scale=1)

# Figure 5-11
ggplot(states, aes(knowgov, turnout, label = st)) +
  geom_point(col="#bf0000") +
  ggtitle("Figure 5-11: Turnout Not Related to Political Knowledge") +
  ylab("Voting Turnout") +
  xlab("Political Knowledge") +
  theme_minimal() +
  geom_text_repel(size = 2.8,
  aes(label=ifelse(st=="HI" | st=="MA", as.character(st),''),
    hjust = 0, vjust=-1), show.legend=FALSE) +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold"))

# Figure 5-12
ggplot(states, aes(hsdiploma, infant)) +
  geom_point(col="#bf0000") +
  ggtitle("Figure 5-12: Education Reduces Infant Mortality") +
  ylab("Infant Mortality") +
  xlab("High School Diploma") +
  theme_minimal() +
  geom_text_repel(size = 2.8,
  aes(label=ifelse(st=="CA" | st=="LA", as.character(st),''),
   hjust = 0, vjust=-1), show.legend=FALSE) +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold"))

# Figure 5-13
ggplot(states, aes(hsdiploma, infant)) +
  geom_point(col="#bf0000") +
  geom_smooth(method = "lm", se = FALSE, col="#0000bf") +
  ggtitle("Figure 5-13: Same Education, Different Outcome") +
  ylab("Infant Mortality") +
  xlab("High School Diploma") +
  theme_minimal() +
  geom_text_repel(size = 2.8,
  aes(label=ifelse(st=="CA" |st=="LA", as.character(st),''),
   hjust = 0, vjust=-1), show.legend=FALSE) +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold"))

# Figure 5-14
ggplot(world, aes(ethfrac, log(gdppc))) +
  geom_point(color=ifelse(world$aclpregion=="Industrial Countries",
                          "#0000bf", "#bf0000")) +
  geom_text_repel(size = 2.8,
                  aes(label=ifelse(iso3c=="COM" |
                                     iso3c=="HTI" |
                                     iso3c=="KIR" |
                                     iso3c=="SLB",
                                   as.character(iso3c),''))) +
  geom_smooth(method="lm", col="grey", se=FALSE,
              linetype = "dashed") +
  ggtitle("Figure 5-14: The Relationship Could Be Nonlinear") +
  ylab("GDP per Capita (logged)") +
  xlab("Ethnolinguistic Fractionalization (ELF)") +
  theme_minimal() +
  geom_smooth(data=subset(world,
  aclpregion != "Industrial Countries"),
  color="black", se=FALSE) +
  annotate("text", x = .15, y = 11.5, size = 3,
            label = "Industrial Countries", col="#0000bf") +
            theme(plot.title = element_text(size = 8, face = "bold")) +
            theme(axis.title = element_text(size = 8, face = "bold"))

# Code Chunk 5-17
cor(world$ethfrac, log(world$gdppc), method = "pearson", use = "complete.obs")
#[1] -0.3791241

# Figure 5-15
ggplot(subset(nes, pid7!="NA" & pid7!="Not sure"), aes(pid7, ftgay)) +
  geom_boxplot(col="#0000ff") +
  theme_minimal() +
  theme(axis.text.x = element_text(size=8, angle=0, vjust=.7)) +
  ggtitle("Figure 5-15: Partisanship Shapes Attitudes") +
  ylab("Gay Thermometer") +
  xlab("Party Identification") +
  coord_flip() +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold"))

# Figure 5-16
ggplot(world, aes(regime, gtbeduc, na.rm=TRUE)) +
  geom_boxplot(col="#0000ff", na.rm=TRUE) +
  theme_minimal() +
  ggtitle("Figure 5-16: Large Variation Under Authoritarian Regimes") +
  ylab("Ratio of Girls-to-Boys Educational Achievement") +
  xlab("") +
  coord_flip() +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold"))

# Figure 5-17
regimedata <- subset(world, regime=="Civilian Dictatorship" |
                       regime=="Military Dictatorship")

ggplot(regimedata, aes(regime, gtbeduc, na.rm=TRUE)) +
  geom_boxplot(outlier.colour=NA, fill=NA, colour="grey20") +
  geom_text_repel(size = 2.8, aes(label = iso3c), col = "grey",
  position = position_jitter(seed = 1), hjust=2, vjust=1) +
  geom_point(aes(fill = regime), size=5, shape=21, colour="grey",
  position=position_jitter(seed = 1)) +
  theme_minimal() +
  ggtitle("Figure 5-17: Dictatorships Especially Bad for Girls") +
  ylab("Ratio of Girls-to-Boys \n Educational Achievement") +
  xlab("") +
  scale_fill_manual(values=c("#0000ff", "#bf0000")) +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold")) +
  theme(legend.position = "none")

# Figure 5-18
nes$f.obama <- as.factor(nes$ftobama)

ggplot(nes, aes(f.obama, ftmuslim)) +
  geom_boxplot(col="#0000bf") +
  theme_minimal() +
  theme(axis.text.x=element_blank(),
  axis.ticks.x=element_blank()) +
  ggtitle("Figure 5-18: Too Many Categories!") +
  ylab("Muslim Thermometer") +
  xlab("Obama Thermometer") +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold"))

# Code Chunk 5-22
nes$pid3.new <- ifelse(nes$pid3 == "Other", NA,
                ifelse(nes$pid3 == "Not sure", NA, nes$pid3))

# Code Chunk 5-23
nes$pid3.new <- as.factor(nes$pid3.new)

levels(nes$pid3.new)=c("Democrat", "Republican", "Independent")

nes$pid3.new = factor(nes$pid3.new,levels(nes$pid3.new)
                      [c(1,3,2)])

table(nes$pid3)
table(nes$pid3.new)


# Figure 5-19
ggplot(data = subset(nes, pid3.new!="NA")) +
  geom_mosaic(aes(x = product(gender, pid3.new),
  fill=gender,na.rm=TRUE)) +
  xlab("") +
  ylab("") +
  ggtitle("Figure 5-19: Independents Are More Masculine") +
  theme_minimal() +
  scale_fill_brewer(palette="Blues") +
  theme(legend.position = "none") +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold"))


# Table 5-3
CrossTable(nes$gender, nes$pid3.new,
           main="Cross-Tabulation of Gender and Party ID",
           prop.chisq=FALSE)

#Code Chunk 5-26
nes$var2 <- droplevels(nes$terror_worry, "Not asked")


# Figure 5-20
ggplot(data = subset(nes, pid3.new!="NA" & var2 !="NA")) +
  geom_mosaic(aes(x = product(var2, pid3.new), fill=var2, na.rm=TRUE)) +
  xlab("") +
  ylab("") +
  ggtitle("Figure 5-20: Democrats Are Less Worried About Terrorism") +
  theme_minimal() +
  scale_fill_brewer(palette="Blues") +
  theme(legend.position = "none") +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold"))

# Table 5-4
CrossTable(nes$var2, nes$pid3.new,
           main="Cross-Tabulation of Fear of Terrorism and Party ID",
           prop.chisq=FALSE)

# Figure 5-21
ggplot(states, aes(hsdiploma, femleg)) +
  geom_point(aes(size=evangel), col="#0000bf") +
  theme_minimal() +
  ggtitle("Figure 5-21: Women Legislators, Education, and Evangelism") +
  ylab("Percentage of Legislature That Are Women") +
  xlab("Percentage of the State’s Population With High School Diploma") +
  scale_size(range = c(.1, 12), name="Evangelism") +
  geom_text(size = 2.8,
  aes(label=ifelse(st=="CA" |
                   st=="LA" |
                   st=="UT" |
                   st=="SC" |
                   st=="NV" |
                   st=="PA" |
                   st=="MD", as.character(st),''),
                  hjust = 2.1, vjust=-1), show.legend=FALSE) +
                  theme(plot.title = element_text(size = 8, face = "bold")) +
                  theme(axis.title = element_text(size = 8, face = "bold"))
# Figure 5-22
ggplot(world, aes(polity2, inf)) +
geom_point(col="#bf0000") +
           geom_smooth(method="lm", se = FALSE) +
           theme_minimal() +
           ggtitle("Figure 5-22: Democracy’s Weak Effect on Infant Mortality") +
           ylab("Deaths per 1,000 Live Births") +
           xlab("Polity Score") +
           theme(plot.title = element_text(size = 8, face = "bold")) +
           theme(axis.title = element_text(size = 8, face = "bold"))

# Figure 5-23
ggplot(world, aes(polity2, inf)) +
  geom_point(aes(size = gdppc), col = "#bf0000") +
  ggtitle("Figure 5-23: Democracy Has a Weak Effect on Infant Mortality") +
  ylab("Deaths per 1,000 Live Births") +
  xlab("Polity Score") +
  scale_size(name="GDP per Capita") +
  theme_minimal() +
  geom_text(size = 2.8,
            aes(label=ifelse(iso3c=="SAU" |
                             iso3c=="SGP" |
                             iso3c=="QAT",
                             as.character(iso3c), ''),
                             hjust = -.5, vjust=-2),
                             show.legend=FALSE) + 
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold"))

# Figure 5-24
ggplot(world, aes(polity2, inf)) +
  geom_point(aes(size = gdppc), col="#bf0000") +
  theme_minimal() +
  geom_text(size = 2.8,
  aes(label=ifelse(iso3c=="QAT" |
                   iso3c=="SAU" |
                   iso3c=="SGP",
                   as.character(iso3c),''),
                  hjust = -.5, vjust=-2),
                  show.legend=FALSE) +
  ggtitle("Figure 5-24: Authoritarian Regimes With Low Infant Mortality Rates") +
  ylab("Deaths per 1,000 Live Births") +
  xlab("Polity Score") +
  scale_size(name = "GDP per Capita") + 
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold"))

          
# Chapter 6: Transforming Data

# Figure 6-1
ggplot(world, aes(gdppc, co2)) +
  geom_point(col="#bf0000") +
  geom_text_repel(size = 2.8,
  aes(label=ifelse(gdppc > 50000 | co2 > 2,
  as.character(iso3c),''),
  hjust = 0, vjust=-1),
  show.legend=FALSE) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold")) +
  ggtitle("Figure 6-1: Difficult Plot to Analyze") +
  ylab("CO2 Emissions (kg per 2000 US$ of GDP)") +
  xlab("GDP per Capita")

# Figure 6-2
ggplot(world, aes(log(gdppc), log(co2))) +
  geom_point(col="#bf0000") +
  geom_smooth(se=FALSE) +
  geom_text_repel(size = 2.8,
                  aes(label=ifelse(gdppc > 50000 | co2 > 2,
                  as.character(iso3c),''),
                  hjust = 1, vjust= -1),
                  show.legend=FALSE) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold")) +
  geom_smooth(data=subset(world,
                          iso3c != "KWT" &
                          iso3c != "QAT" &
                          iso3c != "BRN" &
                          iso3c != "ARE"),
                          color="green", se=FALSE) +
  ggtitle("Figure 6-2: Difficult Plot to Analyze") +
  ylab("CO2 Emissions (kg per $2,000 USD of GDP)") +
  xlab("GDP per Capita")
           
# Figure 6-3
ggplot(nes, aes(birthyr, fttrump)) +
  geom_point(col="#bf0000") +
  ggtitle("Figure 6-3: Feelings Toward Trump and Year of Birth") +
  ylab("Trump Thermometer") +
  xlab("Year of Birth") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold"))

# Code Chunk 6-4
nes$age <- 2016 - nes$birthyr
nes$age5 = cut(nes$age, c(17,31,41,51,61,99,120))  

# Figure 6-4
ggplot(nes, aes(age5, fttrump)) +
  geom_boxplot(col="#0000bf") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold")) +
  ggtitle("Figure 6-4: Trump Thermometer by Age") +
  ylab("Trump Thermometer") +
  xlab("Age of Respondent")

# Figure 6-5
ggplot(world, aes(polity2, log(gdppc))) +
  geom_point(col="#bf0000") +
  geom_smooth(se=FALSE, col="#0000bf") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold")) +
  ggtitle("Figure 6-5: U-Shaped Pattern") +
  ylab("GDP per Capita") +
  xlab("Democracy (Polity2)")

# Code Chunk 6-7
world$regimetype <- ifelse(world$polity2 > 5, 1, 0)
world$regimetype <- factor(world$regimetype,
                           levels = c(0, 1),
                           labels = c("Dictatorship", "Democracy"))
# Figure 6-6
ggplot(subset(world, regimetype !="NA"), aes(regimetype, log(gdppc))) +
  geom_boxplot(col="#0000bf") +
  geom_smooth(method="lm", se=FALSE) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold")) +
  ggtitle("Figure 6-6: Previous Patterns Go Unobserved") +
  ylab("GDP per Capita") +
  xlab("Democracy (Polity2)")

# Code Chunk 6-9
nes$faminc.f <- as.factor(nes$faminc)
nes$nfam <- nes$faminc
nes$nfam[nes$nfam > 16] <- NA

#Code Chunk 6-10
nes$faminc4=cut(nes$nfam,breaks=c(0,3,7,10,16))
levels(nes$faminc4)=c("Low", "MedLow", "MedHigh", "High")

# Figure 6-7
ggplot(nes, aes(faminc.f, fttrump)) +
  geom_boxplot(col="#0000bf") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold")) +
  ggtitle("Figure 6-7: Boxplot Has Too Many Categories") +
  ylab("Trump Thermometer") +
  xlab("Family Income") +
  coord_flip()

# Figure 6-8
ggplot(subset(nes, faminc4!="NA"), aes(faminc4, fttrump)) +
  geom_boxplot(col="#0000bf") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold")) +
  ggtitle("Figure 6-8: Trump Is a Middle-Class Phenomenon") +
  ylab("Trump Thermometer") +
  xlab("Family Income") +
  coord_flip()

# Code Chunk 6-13
nes$newfin <- ifelse(nes$finwell== "The same as 20 years ago" |
                       nes$finwell== "A little worse" |
                       nes$finwell== "Moderately worse" |
                       nes$finwell== "A great deal worse", 0, 1)

nes$newfin <- factor(nes$newfin, levels = c(0,1),
                     labels = c("Worse", "Better"))

# Figure 6-9
ggplot(subset(nes, finwell!="Skipped"), aes(newfin, fttrump)) +
  geom_boxplot(col="#0000bf") +
  theme_minimal() +
  ylab("Trump Thermometer") +
  xlab("") +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold")) +
  ggtitle("Figure 6-9: Do You Feel Financially Better or Worse-Off Than 20 Years Ago?") + 
  coord_flip()

# Figure 6-10
ggplot(subset(nes, finwell!="Skipped"), aes(finwell, fttrump)) +
  geom_boxplot(col="blue") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold")) +
  ggtitle("Figure 6-10: Do You Feel Financially Better Off Than 20 Years Ago?") +
  ylab("Trump Thermometer") +
  coord_flip() +
  ylab("Trump Thermometer") +
  xlab("")

# Figure 6-11
options(scipen = 999)

p1 <- ggplot(world, aes(gdppc)) +
      geom_histogram(bins=10, fill = "#0000bf") +
      labs(title = paste("A")) +
      xlab("GDP per Capita") +
      ylab("Count") +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold")) +
      theme(axis.title = element_text(size = 8, face = "bold"))

p2 <- ggplot(world, aes(log(gdppc))) +
        geom_histogram(bins=10, fill = "#0000bf") +
        labs(title = paste("B")) +
        xlab("GDP per Capita (logged)") +
        ylab("Count") +
        theme_minimal() +
        theme(plot.title = element_text(size = 8, face = "bold")) +
        theme(axis.title = element_text(size = 8, face = "bold"))


grid.arrange(p1, p2, ncol=2, top = textGrob("Figure 6-11: Panel A and Panel B", 
                                            gp=gpar(fontsize=10, fontface = "bold")))


# Figure 6-12 
p3 <- ggplot(world, aes(gdppc/1000, womleg)) + theme_minimal() +
      geom_point(col="#bf0000") +
      labs(title = paste("A")) +
      ylab("Percent of Legislators That Are Women") +
      xlab("GDP per Capita (in thousands)") +
      theme(plot.title = element_text(size = 8, face = "bold")) +
      theme(axis.title = element_text(size = 8, face = "bold"))

p4 <- ggplot(world, aes(log(gdppc), womleg)) +
      geom_point(col="#bf0000") + theme_minimal() +
      labs(title = paste("B")) +
      xlab("GDP per Capita (logged)") +
      ylab("") +
      theme(plot.title = element_text(size = 8, face = "bold")) +
      theme(axis.title = element_text(size = 8, face = "bold"))

grid.arrange(p3, p4, ncol=2, top = textGrob("Figure 6-12: Panel A and Panel B", 
                                            gp=gpar(fontsize=10, fontface = "bold")))


# Figure 6-13
p1 <- ggplot(world, aes(gdppc)) +
      geom_histogram(bins=10, fill = "#0000bf") +
      labs(title = paste("A")) +
      xlab("GDP per Capita") +
      ylab("Count") + 
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold")) +
      theme(axis.title = element_text(size = 8, face = "bold"))

p2 <- ggplot(world, aes(sqrt(gdppc))) +
      geom_histogram(bins=10, fill = "#0000bf") +
      labs(title = paste("B")) +
      xlab("GDP per Capita (square root)") +
      ylab("Count") + 
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold")) +
      theme(axis.title = element_text(size = 8, face = "bold"))

p3 <- ggplot(world, aes(log(gdppc))) +
      geom_histogram(bins=10, fill = "#0000bf") +
      labs(title = paste("C")) +
      xlab("GDP per Capita (logged)") +
      ylab("Count") + 
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold")) +
      theme(axis.title = element_text(size = 8, face = "bold"))

p4 <- ggplot(world, aes(1/gdppc)) +
      geom_histogram(bins=10, fill = "#0000bf") +
      labs(title = paste("D")) +
      xlab("GDP per Capita (inverse)") +
      ylab("Count") + 
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold")) +
      theme(axis.title = element_text(size = 8, face = "bold"))

grid.arrange(p1, p2, p3, p4, ncol=2, nrow=2, 
             top = textGrob("Figure 6-13: Panel A, Panel B, Panel C, and Panel D", 
                            gp=gpar(fontsize=10, fontface = "bold")))

# Figure 6-14
p1 <- ggplot(world, aes(gdppc, pwthc, label=iso3c)) +
      geom_point(col="#bf0000", size=0.5) +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold")) +
      theme(axis.title = element_text(size = 8, face = "bold")) +
      ggtitle("Figure 6-14: Four Transformations") +
      ylab("") +
      xlab("\n Raw GDP per Capita") +
      geom_text(size=3, data=subset(world, iso3c=="QAT"),
      aes(label=iso3c), hjust=1, vjust=2,
      show.legend=FALSE)
      
p2 <- ggplot(world, aes(sqrt(gdppc), pwthc)) +
      geom_point(col="#bf0000", size=0.5) +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold")) +
      theme(axis.title = element_text(size = 8, face = "bold")) +
      ylab("") +
      xlab("\n Square Root") +
      geom_text(size=3, data=subset(world, iso3c=="QAT"),
      aes(label=iso3c), hjust=1, vjust=2,
      show.legend=FALSE)

p3 <- ggplot(world, aes(log(gdppc), pwthc)) +
      geom_point(col="#bf0000", size=0.5) +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold")) +
      theme(axis.title = element_text(size = 8, face = "bold")) +
      ylab("") +
      xlab("\n Logged (base 10)") +
      geom_text(size=3, data=subset(world, iso3c=="QAT"),
      aes(label=iso3c), hjust=.5, vjust=2,
      show.legend=FALSE)

p4 <- ggplot(world, aes(1/gdppc, pwthc)) +
      geom_point(col="#bf0000", size=0.5) +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold")) +
      theme(axis.title = element_text(size = 8, face = "bold")) +
      ylab("") +
      xlab("\n Inverse") +
      geom_text_repel(size=3, data=subset(world, iso3c=="QAT"),
      aes(label=iso3c), hjust=-2, vjust=4,
      show.legend=FALSE)

gridExtra::grid.arrange(p1,p2,p3,p4)


# Chapter 7: Some Principles of Displaying Data

# Figure 7-1
ggplot(world, aes(ethfrac, log(gdppc), col=aclpregion)) +
      geom_point() +
      ggtitle("Figure 7-1: Ethnolinguistic Fractionalization Influences GDP per Capita") +
      ylab("GDP per Capita (logged)") +
      xlab("Ethnolinguistic Fractionalization") +
      theme(plot.title = element_text(size = 8, face = "bold")) +
      theme(axis.title = element_text(size = 8, face = "bold"))

# Figure 7-2
ggplot(world, aes(ethfrac, log(gdppc))) +
      geom_point(color=ifelse(world$aclpregion=="Industrial Countries",
      "#0000bf", "grey")) +
      ggtitle("Figure 7-2: Cleaned-Up Version of Figure 7-1") +
      ylab("GDP per Capita (logged)") +
      xlab("Ethnolinguistic Fractionalization") +
      annotate("text", x=.15, y = 11.5, label = "Industrial Countries",
      col="#0000bf") +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold")) +
      theme(axis.title = element_text(size = 8, face = "bold"))

# Figure 7-3
ggplot(world, aes(ethfrac, log(gdppc), color = aclpregion)) +
  geom_point() +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold")) +
  geom_smooth(method="lm", se=FALSE) +
  ggtitle("Figure 7-3: Colorfully Confusing") +
  ylab("GDP per Capita (logged)") +
  xlab("Ethnolinguistic Fractionalization")

# Figure 7-4
ggplot(world, aes(ethfrac, log(gdppc), by=aclpregion)) +
      geom_point(color=ifelse(world$aclpregion=="Southeast Asia", "black",
      ifelse(world$aclpregion=="Pacific Islands/Oceania",
      "#0000bf", "grey"))) +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold")) +
      theme(axis.title = element_text(size = 8, face = "bold")) +
      geom_smooth(data=subset(world,
                              aclpregion == "Southeast Asia"),
                              color="black", method="lm", se=FALSE) +
      geom_smooth(data=subset(world,
                              aclpregion == "Pacific Islands/Oceania"), color="blue", method="lm", se=FALSE) +
      geom_smooth(data=subset(world,
                              aclpregion != "Southeast Asia" &
                              aclpregion != "Pacific Islands/Oceania"),
                              color="grey", method="lm", se=FALSE) +
      ggtitle("Figure 7-4: These Two Are Not Like the Others") +
      ylab("GDP per Capita (logged)") +
      xlab("Ethnolinguistic Fractionalization") +
      annotate("text", x = .85, y = 10.5,
      label = "Southeast Asia", col="black") +
      annotate("text", x = .12, y = 7.1,
      label = "Pacific Islands/Oceania", col="#0000bf")  

# Figure 7-5
ggplot(world, aes(ethfrac, log(gdppc))) +
      geom_point(color="red") +
      ggtitle("Figure 7-5: GDP per Capita Versus Ethnolinguistic Fractionalization") +
      ylab("GDP per Capita (logged)") +
      xlab("Ethnolinguistic Fractionalization") +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold")) +
      theme(axis.title = element_text(size = 8, face = "bold"))

# Figure 7-6
ggplot(world, aes(ethfrac, log(gdppc), label = iso3c)) +
      geom_point(color=ifelse(world$aclpregion=="Industrial Countries", "blue",
      ifelse(world$aclpregion=="Sub-Saharan Africa", "black", "grey"))) +
      geom_smooth(method="lm", se=FALSE, col="grey", linetype = "dashed") +
      geom_smooth(data=subset(world,
                          aclpregion != "Industrial Countries"),
              color="black", se=FALSE) +
      ggtitle("Figure 7-6: ELF Lowers Income") +
      ylab("GDP per Capita (logged)") +
      xlab("Ethnolinguistic Fractionalization (ELF)") +
      annotate("text", x = .12, y = 11.2,
            label = "Industrial Countries", col="blue") +
      annotate("text", x = .75, y = 6.5,
            label = "Sub-Saharan Africa", col="black") +
      theme_minimal() +
      theme(axis.title = element_text(size = 8, face = "bold")) +
      geom_text(size = 3, col="blue",
                  aes(label=ifelse(iso3c=="COM" |
                                   iso3c=="HTI" |
                                   iso3c=="SLB" |
                                   iso3c=="KIR",
                                   as.character(iso3c),''),
                      hjust = 0, vjust=-1), show.legend=FALSE)

# Figure 7-7
ggplot(subset(nes, pid7!="Other" & pid7!="Not sure"), aes(pid7)) +
      geom_bar(fill="#0000bf") +
      xlab("") +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold")) +
      theme(axis.title = element_text(size = 8, face = "bold")) +
      coord_flip() +
      ggtitle("Figure 7-7: Bar Plot of Party ID") +
      ylab("Number of Respondents")


# Code Chunk 7-8
count(nes$pid7)
# A tibble: 9 x 2
#pid7                  n
#<fct>             <int>
#1 Strong Democrat     295
#2 Weak Democrat       141
#3 Lean Democrat       107
#4 Independent         201
#5 Lean Republican     109
#6 Weak Republican     114
#7 Strong Republican   157
#8 Not sure             40
#9 NA                   14

# Figure 7-8
ggplot(world, aes(ethfrac, log(gdppc))) +
  geom_point()

# Figure 7-9
ggplot(world, aes(ethfrac, log(gdppc))) + geom_point() +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold")) +
  theme(axis.title = element_text(size = 8, face = "bold")) +
  ggtitle("Figure 7-9: Ethnolinguistic Fractionalization Influences GDP per Capita") +
  ylab("GDP per Capita (logged)") +
  xlab("Ethnolinguistic Fractionalization") +
  geom_text_repel(size=3, aes(label = iso3c, size = 1,
                              hjust = 0, vjust=-1))

# Figure 7-10
ggplot(world, aes(ethfrac, log(gdppc))) +
      geom_point(col="#bf0000") +
      theme_minimal() +
      ggtitle("Figure 7-10: Ethnolinguistic Fractionalization Influences GDP per Capita") +
      ylab("GDP per Capita (logged)") +
      xlab("Ethnolinguistic Fractionalization") +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold")) +
      theme(axis.title = element_text(size = 8, face = "bold")) +
      geom_text(size = 2, 
      aes(label = iso3c, size = 1, hjust = 0, vjust=-1),
      col="grey", show.legend=FALSE, data = subset(world, region!="Europe")) +
      geom_text_repel(size = 2, 
            aes(label = iso3c, size = 1, hjust=1, vjust=-1),
            col="grey", show.legend=FALSE, data = subset(world, region=="Europe"))

# Figure 7-11
world$reg <- ifelse(world$regime=="Parliamentary Democracy", 1,
             ifelse(world$regime=="Presidential Democracy", 1, 0))

world$reg <- as.factor(world$reg)

ggplot(world, aes(ethfrac, log(gdppc), col=region, shape=reg)) +
      geom_point() +
      ggtitle("Figure 7-11: Ethnolinguistic Fractionalization Influences GDP per Capita") +
      ylab("GDP per Capita (logged)") +
      xlab("Ethnolinguistic Fractionalization") +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold"),
      axis.title = element_text(size = 8, face = "bold"),
      legend.title = element_text(size = 8, face = "bold"),
      legend.position="bottom", 
      legend.background = element_rect(fill="white", size=0.5, linetype="solid")) +
      labs(color = "Region", shape = "Regime") +
      geom_text(size=2,
                  aes(label = iso3c, size = 1, hjust = 0, vjust=-1),
                  col=ifelse(world$iso3c=="MDG", "#0000bf",
                             ifelse(world$iso3c=="LUX", "#0000bf", "grey")))
# Figure 7-12

install_github("Gibbsdavidl/CatterPlots")
library(CatterPlots)

x <- 0:20
y <- -x^2 + 10
set.seed(33)

multicat(xs=x, ys=rnorm(21),
         cat=c(1,2,3,4,5,6,7,8,9,10),
         catcolor=c('blue', 'green', 'red', 'purple', 'brown'),
         canvas=c(-.1,1.1, -0.1, 1.1),
         xlab="Number of Faculty Layoffs",
         ylab="Change in Tuition",
         main="Figure 7-12: Tuition and Faculty Layoffs")

# Figure 7-13
ggplot(states, aes(inc, abort)) +
      geom_point(col="grey") +
      geom_smooth(method="lm", se=FALSE, col="#0000bf") +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold")) +
      theme(axis.title = element_text(size = 8, face = "bold")) +
      ggtitle("Figure 7-13: Abortion Is More Available to the Wealthy") +
      ylab("Abortions per 1,000 Women") +
      xlab("Income in Dollars per Capita")

# Figure 7-14
ggplot(states, aes(inc, abort, col = region)) +
       scale_color_manual(values=c("#bf0000", "#00bf00", "#00ffff", "#263333")) +
       geom_point(size=2) +
       theme_minimal() +
       theme(plot.title = element_text(size = 8, face = "bold")) +
       theme(axis.title = element_text(size = 8, face = "bold")) +
       ggtitle("Figure 7-14: Exploring Abortion and Income by Region") +
       ylab("Abortions per 1,000 Women") +
       xlab("Income in Dollars per Capita") +
       annotate("text", x = 45000, y = 30,
       label = "West", col="#00bf00") +
       annotate("text", x = 32000, y = 12,
       label = "South", col="#bf0000") +
       annotate("text", x = 50000, y = 35,
       label = "Northeast", col="#263333") +
       annotate("text", x = 39000, y = 5,
       label = "Midwest", col="#00ffff") +
       guides(col=FALSE, shape=FALSE)

# Figure 7-15
ggplot(states, aes(inc, abort, label = "state")) +
      geom_point(size = 2.5, col=ifelse(states$region=="South", "#0000bf", "grey")) +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold")) +
      theme(axis.title = element_text(size = 8, face = "bold")) +
      ggtitle("Figure 7-15: Explaining Abortion and Income") +
      ylab("Abortions per 1,000 Women") +
      xlab("Income in Dollars per Capita") +
      annotate("text", x = 32000, y = 12,
            label = "South", col="blue") +
      guides(col=FALSE, shape=FALSE)

# Figure 7-16
ggplot(states, aes(inc, abort, col = region)) +
      geom_point(size=log(states$density)) +
      scale_color_manual(values=c("#bf0000", "#00bf00", "#00ffff", "#263333")) +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold")) +
      theme(axis.title = element_text(size = 8, face = "bold")) +
      geom_text(size=2.5,label=states$st, col="grey", vjust=-2) +
      ggtitle("Figure 7-16: Abortion in the United States") +
      ylab("Abortions per 1,000 Women") +
      xlab("Income in Dollars per Capita") +
      annotate("text", x = 45000, y = 30,
               label = "West", col="#00bf00") +
      annotate("text", x = 32000, y = 12,
               label = "South", col="#bf0000") +
      annotate("text", x = 50000, y = 35,
               label = "Northeast", col="#263333") +
      annotate("text", x = 39000, y = 5,
               label = "Midwest", col="#00ffff") +
      guides(col=FALSE, shape=FALSE) +
      annotate("text", x = 52000, y = 17, label = "Mean of Y", col="grey") +
      annotate("text", x = 42200, y = 41, label = "Mean of X", col="grey") +
       annotate("text", x = 52000, y = 12,
                label = "Point size = log of population density", col="grey") +
      guides(col=FALSE, shape=FALSE) +
      geom_hline(aes(yintercept = mean(states$abort)), col="grey", 
                 linetype = "dashed") +
      geom_vline(aes(xintercept = mean(states$inc)), col="grey",
                 linetype = "dashed")

# Chapter 8: The Essentials of Probability Theory

# Code Chunk 8-1
set.seed(3376)
mu=100; sigma=10; n=10

# Code Chunk 8-2
xbar1=rep(0,5)
for (i in 1:5) {xbar1[i]= mean(rnorm(n, mean=mu, sd=sigma))}

#Code Chunk 8-3
mu=100; sigma=10; n=10
xbar2=rep(0,10)
for (i in 1:10) {xbar2[i]=mean(rnorm(n, mean=mu, sd=sigma))}

mu=100; sigma=10; n=10
xbar3=rep(0,100)
for (i in 1:100) {xbar3[i]=mean(rnorm(n, mean=mu, sd=sigma))}

#Code Chunk 8-4
x <- list(v1=xbar1,v2=xbar2,v3=xbar3)
data <- melt(x)

# Figure 8-2
xb1 <- mean(xbar1)
xb2 <- mean(xbar2)
xb3 <- mean(xbar3)

xb1 # 98.89503
xb2 # 100.4808
xb3 # 100.071

ggplot(data,aes(x=value, fill=L1)) +
       geom_density(alpha=.50) +
       ggtitle("Figure 8-2: Increased Draws, Increased Accuracy") +
       xlab("Value") + 
       ylab("Density") +
       theme_minimal() +
       theme(plot.title = element_text(size = 8, face = "bold")) +
       theme(axis.title = element_text(size = 8, face = "bold")) +
       geom_vline(xintercept=xb1, col="#bf0000") +
       geom_vline(xintercept=xb2, col="#008b00") +
       geom_vline(xintercept=xb3, col="#0000ff") +
       annotate("text", x = 95, y = .15, label =
                "Mean with 5 draws = 98.895", col="#bf0000") +
       annotate("text", x = 95, y = .175, label =
                "Mean with 10 draws = 100.481", col="#008b00") +
       annotate("text", x = 95, y = .20, label =
                "Mean with 100 draws = 100.071", col="#0000ff") +
       theme(legend.position = "none")

# Code Chunk 8-6
set.seed(3376)
mu=100; sigma=10; n=5
xbar1=rep(0,10)
for (i in 1:10) {xbar1[i]=mean(rnorm(n, mean=mu, sd=sigma))}

mu=100; sigma=10; n=10
xbar2=rep(0,10)
for (i in 1:10) {xbar2[i]=mean(rnorm(n, mean=mu, sd=sigma))}

mu=100; sigma=10; n=100
xbar3=rep(0,10)
for (i in 1:10) {xbar3[i]=mean(rnorm(n, mean=mu, sd=sigma))}


# Figure 8-3
x <- list(v1=xbar1,v2=xbar2,v3=xbar3)
data <- melt(x)

xb1 <- sd(xbar1)
xb2 <- sd(xbar2)
xb3 <- sd(xbar3)

xb1 <- mean(xbar1)
xb2 <- mean(xbar2)
xb3 <- mean(xbar3)

xb1
xb2
xb3

ggplot(data,aes(x=value, fill=L1)) +
      geom_density(alpha=.70) +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold")) +
      theme(axis.title = element_text(size = 8, face = "bold")) +
      ggtitle("Figure 8-3: Increasing Observations Increases Normality") +
      annotate("text", x = 95, y = .15, label = 
                  "5 Observations per Draw", col="#bf0000") +
      annotate("text", x = 95, y = .175, label =
                  "10 Observations per Draw", col="#008b00") +
      annotate("text", x = 95, y = .20, label =
                   "100 Observations per Draw", col="#0000ff") +
      theme(legend.position = "none") +
      xlab("Mean of Sample Means") +
      ylab("Density")


# Figure 8-4
set.seed(3376)
mu=100; sigma=10; n=1000

xbar1=rep(0,50)
for (i in 1:50) {xbar1[i]=sum(rnorm(n, mean=mu, sd=sigma))}

x <- data.frame(v1=xbar1)

ggplot(x,aes(x=v1)) +
      geom_density(fill="#0000bf", alpha=.7) +
               theme_minimal() +
               theme(plot.title = element_text(size = 8, face = "bold")) +
               theme(axis.title = element_text(size = 8, face = "bold")) +
               ggtitle("Figure 8-4: Sampling Distribution of Sums Is Normal") +
               xlab("Sum of Sample") +
               ylab("Density") +
               theme(legend.position = "none")

# Figure 8-5
set.seed(3376)
mu=100; sigma=10; n=5
xbar1=rep(0,100)
for (i in 1:100) {xbar1[i]=mean(rnorm(n, mean=mu, sd=sigma))}

x <- data.frame(v1=xbar1)
xb1 <- mean(x$v1)

ggplot(x,aes(x=v1)) +
      geom_density(fill="#0000ff", alpha=.7) +
                  theme_minimal() +
                  theme(plot.title = element_text(size = 8, face = "bold")) +
                  theme(axis.title = element_text(size = 8, face = "bold")) +
      ggtitle("Figure 8-5: Sampling Distribution From Normal Population") +
                 xlab("Mean of Sample") +
                 ylab("Density") +
                 theme(legend.position = "none")

# Code Chunk 8-10
xunif <- runif(100000, min = 50, max = 150)
x <- data.frame(xunif)

p <- ggplot(x, aes(xunif)) +
     geom_density(alpha=.7, fill="#0000ff") +
     theme_minimal() +
     theme(plot.title = element_text(size = 8, face = "bold")) +
     theme(axis.title = element_text(size = 8, face = "bold")) +
     annotate("text", x = 80, y = .012, label =
              "Mean = 100", col="#bf0000") +
     geom_vline(xintercept=100, col="#bf0000") +
     ggtitle("Figure 8-6a: Uniform Distribution") +
     xlab("Uniform Distribution") +
     ylab("Density")

# Figures 8-6 a and b
set.seed(3376)
min=50; max=150; n=50
xbar1=rep(0,500)
for (i in 1:500) {xbar1[i]=mean(runif(n, min, max))}

x <- data.frame(v1=xbar1)
xb1 <- mean(x$v1)
xb1

p1 <- ggplot(x,aes(x=v1)) +
      geom_density(fill="#0000ff", alpha=.7) +
      geom_vline(xintercept=xb1, col="#bf0000") +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold")) +
      theme(axis.title = element_text(size = 8, face = "bold")) +
      annotate("text", x = 107, y = .10, label =
              "Mean = 99.689", col="#bf0000") +
      ggtitle("Figure 8-6b: Sampling Distribution From Uniform Distribution") +
      xlab("Mean of Sample") +
      ylab("Density") +
      theme(legend.position = "none")

grid.arrange(p, p1, ncol=2)

# Code Chunk 8-12
expd <- rexp(100000, rate = .01)
xexp <- data.frame(expd)

p <- ggplot(xexp, aes(expd)) +
     geom_density(alpha=.7, fill="#0000ff") +
     theme_minimal() +
     theme(plot.title = element_text(size = 8, face = "bold")) +
     theme(axis.title = element_text(size = 8, face = "bold")) +
     annotate("text", x = 300, y = .008, label =
              "Mean = 100", col="#bf0000") +
     geom_vline(xintercept=100, col="#bf0000") +
     ggtitle("Figure 8-7a: Exponential Distribution") +
     xlab("Exponential Distribution") +
     ylab("Density")

# Figures 8-7 a and b
set.seed(3376)
n=50

xbar1=rep(0,500)
for (i in 1:500) {xbar1[i]=mean(rexp(n, rate = .01))}

x <- data.frame(xbar1)
xb1 <- mean(x$xbar1)
xb1

p1 <- ggplot(x,aes(xbar1)) +
      geom_density(fill="#0000ff", alpha=.7) +
      geom_vline(xintercept=xb1, col="red") +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold")) +
      theme(axis.title = element_text(size = 8, face = "bold")) +
      annotate("text", x = 125, y = .027, label =
               "Mean = 100.774", col="#bf0000") +
      ggtitle("Figure 8-7b: Sampling Distribution From Exponential \n Distribution") +
      xlab("Mean of Sample") +
      ylab("Density") +
      theme(legend.position = "none")
  

grid.arrange(p, p1, ncol=2)


# Code Chunk 8-14
set.seed(3376)
n=500
y1 = rnorm(n, 75, 10); y2 = rnorm(n, 125, 10)
w = rbinom(n, 1, .5)
x2 = w*y1 + (1-w)*y2
bm <- data.frame(x2)
bm

p <- ggplot(bm, aes(x2)) +
     geom_density(alpha=.7, fill="#0000ff") +
     theme_minimal() +
     theme(plot.title = element_text(size = 8, face = "bold")) +
     theme(axis.title = element_text(size = 8, face = "bold")) +
     annotate("text", x = 80, y = .017, label =
              "Mean = 100", col="#bf0000") +
     geom_vline(xintercept=100, col="#bf0000") +
     ggtitle("Figure 8-8a: Bimodal Distribution") +
     xlab("Bimodal Distribution") +
     ylab("Density")

# Figures 8-8 a and b
set.seed(3376)
n=50
xbar1=rep(0,500)
for (i in 1:500) {xbar1[i]= mean(sample(bm$x2, n, replace = TRUE))}

x <- data.frame(xbar1)
xb1 <- mean(x$xbar1)
xb1

p1 <- ggplot(x,aes(xbar1)) +
      geom_density(fill="#0000ff", alpha=.7) +
      geom_vline(xintercept=xb1, col="#bf0000") +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold")) +
      theme(axis.title = element_text(size = 8, face = "bold")) +
      annotate("text", x = 110, y = .10, label =
               "Mean = 101.811", col="#bf0000") +
      ggtitle("Figure 8-8b: Sampling Distribution From Bimodal \n Distribution") +
      xlab("Mean From Each Sample") +
      ylab("Density") +
      theme(legend.position = "none")

grid.arrange(p, p1, ncol=2)

# Figure 8-9
mean=0; sd=1
lb= -1; ub=1

x <- seq(-4,4,length=10000)*sd + mean
hx <- dnorm(x,mean,sd)

plot(x, hx, type="n", xlab="", ylab="", main="", axes=FALSE)

i <- x >= lb & x <= ub
lines(x, hx)
polygon(c(lb,x[i],ub), c(0,hx[i],0), col="#0000bf")

area <- pnorm(ub, mean, sd) - pnorm(lb, mean, sd)

result <- paste("P(",lb,"< 0 <",ub,") =", signif(area, digits=3))
mtext(result, 3)
axis(1, at=seq(-5, 5, 1), pos=0)

# Figure 8-10
v1 <- seq(-4, 4, length = 10000)
v2<- dnorm(v1, 0, 1)
df <- data.frame(v1, v2)

ggplot(df, aes(v1, v2)) +
       geom_line() +
       theme_minimal() +
       theme(plot.title = element_text(size = 8, face = "bold")) +
       theme(axis.title = element_text(size = 8, face = "bold")) +
       geom_ribbon(data=subset(df ,v1>1.51 & v1<4),aes(ymax=v2),ymin=0,
       fill="#0000bf",colour=NA) +
       scale_fill_brewer(guide="none") +
       xlab("Standard Deviations From Mean") +
       ylab("Density") +
       ggtitle("Figure 8-10: Original Units of IQ Scores") +
       geom_vline(xintercept = 1.51, linetype=2) +
       scale_x_continuous(sec.axis=sec_axis(~.*2.06+11.88))

# Chapter 9: Confidence Intervals and Testing Hypotheses

# Table 9-1
freq(nes$disc_fed, plot = options(descr.plot = FALSE),
     main="Table 9-1: Most Americans See No Bias")

# Code Chunk 9-2
nes$fed <-
  ifelse(nes$disc_fed=="Treats whites much better", 0,
         ifelse(nes$disc_fed=="Treats whites moderately better", 0,
                ifelse(nes$disc_fed=="Treats whites a little better", 0, 1)))
#table(nes$fed)
#499+679

#Code Chunk 9-3
mean(nes$birthyr)
#[1] 1967.978
sd(nes$birthyr)
#[1] 16.98526

# Code Chunk 9-4
x1 <- seq(-4, 4, length = 10000)
x2 <- dt(x1, df = 1)
x3 <- dnorm(x1)
mydata <- data.frame(x1,x2,x3)

# Figure 9-1
ggplot(mydata, aes(x1)) +
  geom_line(aes(y = x2), col="#0000bf") +
            geom_line(aes(y = x3), col="#bf0000") +
                      theme_minimal() +
                        theme(plot.title = element_text(size = 8, face = "bold"),
                              axis.title = element_text(size = 8, face = "bold")) +
                        xlab("Standard Deviations") +
                        ylab("Density") +
                        ggtitle("Figure 9-1: The t-Distribution Has Fatter Tails")

# Figure 9-2
ggplot(mydata, aes(x1)) +
  geom_line(aes(y = dt(x1, df = 1), col = "#bf0000")) +
  geom_line(aes(y = dt(x1, df = 2), col = "#008b00")) +
  geom_line(aes(y = dt(x1, df = 6), col = "#0000ff")) +
  xlab("Standard Deviations") +
  ylab("Density") +
  ggtitle("Figure 9-2: The t-Distribution Approaches Normality") +
  scale_color_discrete(name = "Degree of Freedom",
  labels = c("df=6", "df=2", "df=1")) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
  axis.title = element_text(size = 8, face = "bold"),
  legend.title = element_text(size = 8),
  legend.position = c(0.75, 0.7))

# Code Chunk 9-7
set.seed(34)
mu=50; sigma=10

xbar1=rep(0,50)
for (i in 1:50) {
  xbar1[i]=sd(rnorm(100, mean=mu, sd=sigma))*sqrt((100-1)/100)}

xbar2=rep(0,50)
for (i in 1:50) {
  xbar2[i]=sd(rnorm(50, mean=mu, sd=sigma))*sqrt((50-1)/50)}

xbar3=rep(0,50)
for (i in 1:50) {
  xbar3[i]=sd(rnorm(10, mean=mu, sd=sigma))*sqrt((10-1)/10)}

xbar4=rep(0,50)
for (i in 1:50) {
  xbar4[i]=sd(rnorm(5, mean=mu, sd=sigma))*sqrt((5-1)/5)}

xbar5=rep(0,50)
for (i in 1:50) {
  xbar5[i]=sd(rnorm(3, mean=mu, sd=sigma))*sqrt((3-1)/3)}

x <- list(v1=xbar1,v2=xbar2,v3=xbar3,v4=xbar4,v5=xbar5)
data <- melt(x)


# Figure 9-3
data$L1 <- factor(data$L1,
                  levels = c("v1","v2","v3","v4","v5"),
                  labels = c("n=100", "n=50", "n=10", "n=5", "n=3"))

ggplot(data,aes(y=value, x=L1)) +
  geom_point(col="#0000bf") +
  stat_summary(aes(y = value, group=1), fun.y="mean", colour="#bf0000",
               geom="line", group=1) +
  ggtitle("Figure 9-3: Sample Standard Deviation Decreases With Smaller n") +
  xlab("Number of Observations in Each Sample") +
  ylab("Sample Standard Deviation") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  geom_hline(yintercept = 10, linetype = "dashed")

# Figure 9-4
set.seed(34)
mu=50; sigma=10

xbar1=rep(0,50)
for (i in 1:50) {xbar1[i]=sd(rnorm(100, mean=mu, sd=sigma))}

xbar2=rep(0,50)
for (i in 1:50) {xbar2[i]=sd(rnorm(50, mean=mu, sd=sigma))}

xbar3=rep(0,50)
for (i in 1:50) {xbar3[i]=sd(rnorm(10, mean=mu, sd=sigma))}

xbar4=rep(0,50)
for (i in 1:50) {xbar4[i]=sd(rnorm(5, mean=mu, sd=sigma))}

xbar5=rep(0,50)
for (i in 1:50) {xbar5[i]=sd(rnorm(3, mean=mu, sd=sigma))}

x <- list(v1=xbar1,v2=xbar2,v3=xbar3,v4=xbar4,v5=xbar5)

data <- melt(x)
data$L1 <- factor(data$L1,
                  levels = c("v1","v2","v3","v4","v5"),
                  labels = c("n=100", "n=50", "n=10", "n=5", "n=3"))

ggplot(data,aes(y=value, x=L1)) +
  stat_summary(aes(y = value,group=1), fun.y="mean",
               colour="#bf0000", geom="line",group=1) +
               geom_point(col="#0000bf") +
                          ggtitle("Figure 9-4: Bias Is Eliminated With n − 1") +
                            xlab("Number of Observations in Each Sample") +
                            ylab("Sample Standard Deviation") +
                            theme_minimal() +
                            theme(plot.title = element_text(size = 8, face = "bold"),
                                  axis.title = element_text(size = 8, face = "bold")) +
                            geom_hline(yintercept = 10, linetype = "dashed")
# Code Chunk 9-10
set.seed(567)
nstates <- tbl_df(states)
rstates <- sample_n(nstates, 30, replace = TRUE)
mean(rstates$percwom)
sd(rstates$percwom)
sd(rstates$percwom)/sqrt(30)
qt(.05, 30)
mean(states$percwom)
sd(states$percwom)


# Figure 9-5
v1 <- seq(-4, 4, length = 10000)
v2<- dt(v1, 30)
df <- data.frame(v1, v2)

ggplot(df, aes(v1, v2)) +
  geom_line() +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  geom_ribbon(data=subset(df ,v1>2.042 & v1<4),aes(ymax=v2),ymin=0,
              fill="#0000bf",colour=NA) +
              geom_ribbon(data=subset(df ,v1< -2.042 & v1> -4),aes(ymax=v2),ymin=0,
                          fill="#0000bf",colour=NA) +
                          scale_fill_brewer(guide="none") +
                            ggtitle("Figure 9-5: A $10 Difference Is Significant") +
                            xlab("Standard Deviations") +
                            ylab("Density") +
                            geom_vline(xintercept = 2.5, linetype=2) +
                            geom_vline(xintercept = -2.5, linetype=2) +
                            scale_x_continuous(sec.axis=sec_axis(~.*4.00+0,
                            name = "Difference in Dollars"))

# Table 9-2
nes$white <- ifelse(nes$race=="White", 1, 0)
p <- t.test(ftpolice ~ white, data=nes)
pander(p)

# Table 9-3
p <- t.test(medinc ~ trumpwin, data = states)
pander(p)

# Table 9-4
set.seed(556)
conf(100, 50, 1, 20, 1.65)

# Table 9-5
set.seed(556)
conf(100, 50, 1, 20, 2.576)

# Chapter 10: Making Comparisons

# Code Chunk 10-1
nes$pid3.new <- ifelse(nes$pid3 == "Other", NA,
                       ifelse(nes$pid3 == "Not sure", NA,
                              nes$pid3))

nes$pid3.new <- as.factor(nes$pid3.new)
levels(nes$pid3.new)=c("Democrat", "Rep.", "Indep.")

nes$pid3.new = factor(nes$pid3.new,levels(nes$pid3.new)[c(1,3,2)])
table(nes$pid3.new)

# The code for constructing 'nes$dpolic.new' was not included in code chunk 10-1

nes$dpolice.new <- ifelse(nes$disc_police=="Treats blacks a little better" |
                            nes$disc_police=="Treats blacks both the same" |
                            nes$disc_police=="Treats blacks moderately better" |
                            nes$disc_police=="Treats Blacks much better" |
                            nes$disc_police=="Skipped", NA, nes$disc_police)
nes$dpolice.new <- as.factor(nes$dpolice.new)
levels(nes$dpolice.new)=c("Treats whites much better", "Treats whites moderately better",
                          "Treats whites a little better", "Treats both the same")


# Figure 10-1
ggplot(data = na.omit(nes)) +
  geom_mosaic(aes(x = product(pid3.new, dpolice.new),
                  fill=pid3.new, na.rm=TRUE)) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  xlab("") +
  ylab("") +
  coord_flip() +
  ggtitle("Figure 10-1: How Do Police Treat Whites and Blacks?") +
  scale_fill_brewer(palette="Blues") +
  theme(legend.position="none")

# Table 10-1

CrossTable(nes$dpolice.new, nes$pid3.new,
           prop.chisq=FALSE)

# Code Chunk 10-4
nanes <- na.omit(nes)
nanes <- subset(nanes, pew_churatd!="Skipped"
                & pew_churatd!="Don’t know")
nanes$pew_churatd <- droplevels(nanes$pew_churatd)


# Figure 10-2

ggplot(nanes) +
  geom_mosaic(aes(x = product(pid3.new, pew_churatd),
                  fill=pid3.new,na.rm=TRUE)) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  xlab("") +
  ylab("") +
  ggtitle("Figure 10-2: Who Goes to Church?") +
  scale_fill_brewer(palette="Blues") +
  theme(legend.position="none") +
  coord_flip()

# Figure 10-3
ggplot(subset(nes, !is.na(pid7)), aes(pid7, ftobama)) +
  geom_boxplot(col="#0000ff") + theme_minimal() +
               theme(plot.title = element_text(size = 8, face = "bold"),
                     axis.title = element_text(size = 8, face = "bold")) +
                 ggtitle("Figure 10-3: Partisanship Determines Obama’s Popularity") +
                 ylab("Obama Thermometer") +
                 xlab("Party Identification") +
                 coord_flip()
# Figure 10-4
ggplot(world, aes(region, polity2, col=region)) +
  geom_jitter() +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  theme(axis.text.x = element_text(size=8, vjust=.7),
        legend.position="none") +
  ggtitle("Figure 10-4: Most Authoritarian Regimes Reside in Africa") +
  ylab("Democracy (Polity2)") +
  xlab("") +
  scale_color_manual(values=c("#0000ff", "#008b00", "#bf0000",
                               "#ff7300", "#00e6e6", "#263333",
                               "#73e600")) +
                               coord_flip()
# Figure 10-5

ggplot(world, aes(gtbeduc, inf)) +
  geom_point(col="#bf0000") +
  geom_text_repel(size=3, vjust=2, col="black",
                  aes(label= ifelse(iso3c=="PAK" |
                                                 iso3c=="YEM" |
                                                 iso3c=="AFG" |
                                                 iso3c=="SDN" |
                                                 iso3c=="SWZ" |
                                                 iso3c=="ETH",
                                               as.character(iso3c), ''))) +
  ggtitle("Figure 10-5: Infant Mortality and Women’s Education") +
  ylab("Infant Mortality: Deaths per 1,000 Live Births") +
  xlab("Ratio of Girls to Boys Educational Attainment") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
  axis.title = element_text(size = 8, face = "bold"))

# Figure 10-6
ggplot(states, aes(femleg, ptratio)) +
  geom_point(col="#bf0000") +
  geom_text_repel(size=3, vjust=2, col="#263333", alpha = .3,
                             aes(label= st)) +
  ggtitle("Figure 10-6: Female Legislators and Key Education Measure") +
  ylab("Student/Teacher Ratio") +
  xlab("Percentage of Seats in Legislature Held by Women") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold"))

# Figure 10-7
ggplot(states, aes(democrat, abort)) + geom_point(col="#bf0000") +
       theme_minimal() +
       theme(plot.title = element_text(size = 8, face = "bold"),
             axis.title = element_text(size = 8, face = "bold")) +
       ggtitle("Figure 10-7: Plot of Abortion Rate and Party ID") +
       ylab("Abortions per 1,000 Women") +
       xlab("Percent That Self-Identifies as Democrat") +
       geom_text_repel(size=3, col="#04183d", aes(label= ifelse(st=="NY" |
                                                                st=="CA" |
                                                                st=="NJ" |
                                                                st=="WY" |
                                                                st=="UT" |
                                                                st=="DE" |
                                                                st=="ID", 
                                                                as.character(st), '')))
# Figure 10-8
ggplot(states, aes(democrat, abort)) +
  geom_point(aes(size=density), col="#0000ff") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
                     axis.title = element_text(size = 8, face = "bold")) +
  theme(legend.position = c(.8, .2)) +
  ggtitle("Figure 10-8: Population Density Matters") +
  ylab("Abortions per 1,000 Women") +
  xlab("Percent of State That Are Democrat") +
  geom_text(size=3, vjust=-1.5, col="#04183d",
                         aes(label= ifelse(st=="NY" |
                                             st=="CA" |
                                             st=="NJ" |
                                             st=="WY" |
                                             st=="UT" |
                                             st=="DE" |
                                             st=="ID", as.character(st), ''))) +
               guides(size=guide_legend("Population Density"))

# Code Chunk 10-12
states$density3 <- cut(states$density, breaks=c(0,50,150,1200))
levels(states$density3)=c("Low", "Med", "High")
states$density3=as.ordered(states$density3)

# Figure 10-9
ggplot(states, aes(democrat, abort, col = density3)) +
  geom_point() + geom_smooth(method="lm", se=FALSE) +
  ggtitle("Figure 10-9: Partisanship Matters in Rural States") +
  ylab("Abortions per 1,000 Women") +
  xlab("Percent of State That Are Democrat") +
  geom_text_repel(size=3, aes(label= ifelse(st=="ND" |
                                              st=="SD" |
                                              st=="UT" |
                                              st=="DE" |
                                              st=="NV" |
                                              st=="WY", as.character(st), ''))) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold"),
        legend.title = element_text(size=8, face = "bold")) +
  theme(legend.position = c(.7, .3)) +
  scale_color_manual(breaks = c("Low", "Med", "High"),
                     values=c("#bf0000", "#0000ff", "#008b00")) +
                               guides(col=guide_legend("Population Density"))

# Figure 10-10
ggplot(states, aes(log(density), abort)) +
  geom_point(col="#bf0000") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  geom_smooth(method="loess", se=FALSE, col="#0000ff") +
  geom_text_repel(size=3, col="#04183d", aes(label= ifelse(st=="NY" |
                                             st=="CA" |
                                             st=="NJ" |
                                             st=="WY" |
                                             st=="UT" |
                                             st=="ID" |
                                             st=="CO" |
                                             st=="OR" |
                                             st=="WI" |
                                             st=="MO" |
                                             st=="IN" |
                                             st=="NV", as.character(st), ''))) +
  ggtitle("Figure 10-10: Abortion Rate and Party ID") +
  ylab("Abortions per 1,000 Women") +
  xlab("Percent of State That Are Democrat (logged)")

# Answers 

#5
nanes$finwell <- droplevels(nanes$finwell)

ggplot(nanes) +
  geom_mosaic(aes(x = product(pid3.new, finwell),
                  fill=pid3.new,na.rm=TRUE)) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  xlab("") +
  ylab("") +
  ggtitle("Democrats Did Well") +
  scale_fill_brewer(palette="Blues") +
  theme(legend.position="none") +
  coord_flip()

# 6 
nanes$finwell <- droplevels(nanes$finwell)

ggplot(nanes) +
  geom_mosaic(aes(x = product(gender, finwell),
                  fill=gender,na.rm=TRUE)) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  xlab("") +
  ylab("") +
  ggtitle("Gender and Financial Well-Being") +
  scale_fill_brewer(palette="Blues") +
  theme(legend.position="none") +
  coord_flip()

# 7
nanes$finwell <- droplevels(nanes$finwell)

ggplot(nanes) +
  geom_mosaic(aes(x = product(gender, pid3.new),
                  fill=gender,na.rm=TRUE)) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  xlab("") +
  ylab("") +
  ggtitle("Independents Are Males") +
  scale_fill_brewer(palette="Blues") +
  theme(legend.position="none") +
  coord_flip()

# 8
ggplot(states, aes(region, femleg, col=region)) +
  geom_boxplot() +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  theme(axis.text.x = element_text(size=8, vjust=.7),
        legend.position="none") +
  ggtitle("Women in Legislatures by Region") +
  ylab("Percentage of Legislators That Are Women") +
  xlab("") +
  coord_flip()

# 9 
ggplot(world, aes(region, ethfrac, col=region)) +
  geom_boxplot() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  theme(axis.text.x = element_text(size=8, vjust=.7),
        legend.position="none") +
  theme_minimal() +
  ggtitle("Ethnolinguistic Fractionalization by Region") +
  ylab("Ethnolinguistic Fractionalization Score") +
  xlab("") +
  coord_flip()

# 10 
ggplot(world, aes(colony, turnout, col=colony)) +
  geom_jitter() +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  theme(axis.text.x = element_text(size=8, vjust=.7),
        legend.position="none") +
  ggtitle("Turnout and Colonial Past") +
  ylab("Percentage of Population Voting in Last Legislative Election") +
  xlab("") +
  coord_flip()

# 11
ggplot(world, aes(womyear, inf)) +
  geom_point(col="#bf0000") +
             geom_text(size=3, vjust=2, col="#263333", alpha = .3,
                       aes(label= iso3c)) +
               ggtitle("Women’s Suffrage and Infant Mortality") +
               ylab("Infant Mortality") +
               xlab("Year Women Were Granted Suffrage") +
               theme_minimal() +
               theme(plot.title = element_text(size = 8, face = "bold"),
                     axis.title = element_text(size = 8, face = "bold"))
# 12 
ggplot(states, aes(inc, stuspend)) +
  geom_point(col="#bf0000") +
             geom_text(size=3, vjust=2, col="#263333", alpha = .3,
                             aes(label= st)) +
               ggtitle("Income and Spending on Students") +
               ylab("Dollars per Student") +
               xlab("Income per Household") +
               theme_minimal() +
               theme(plot.title = element_text(size = 8, face = "bold"),
                     axis.title = element_text(size = 8, face = "bold"))
# 13
ggplot(states, aes(minwage, percwom)) +
  geom_point(col="#bf0000") +
             geom_text(size=3, vjust=2, col="#263333", alpha = .3,
                             aes(label= st)) +
               ggtitle("Women’s Salaries Relative to Men’s and the Minimum Wage") +
               ylab("Women’s Salaries as a Percentage of Men’s") +
               xlab("Minimum Wage") +
               theme_minimal() +
               theme(plot.title = element_text(size = 8, face = "bold"),
                     axis.title = element_text(size = 8, face = "bold"))

# Practice on Analysis and Visualization

# 1
ggplot(data = na.omit(nes)) +
  geom_mosaic(aes(x = product(gender, immig_numb),
                  fill=gender,na.rm=TRUE)) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  xlab("") +
  ylab("") +
  coord_flip() +
  ggtitle("No Gender Differences") +
  scale_fill_brewer(palette="Blues") +
  theme(legend.position="none")

# 2
ggplot(data = na.omit(nes)) +
  geom_mosaic(aes(x = product(warmcause, pid3.new),
                  fill=warmcause,na.rm=TRUE)) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  xlab("") +
  ylab("") +
  ggtitle("Democrats Blame Humans for Climate Change") +
  scale_fill_brewer(palette="Blues") +
  theme(legend.position="none")

# 3
ggplot(data = na.omit(nes)) +
  geom_mosaic(aes(x = product(compromise, pid3.new),
                  fill=compromise,na.rm=TRUE)) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  xlab("") +
  ylab("") +
  ggtitle("Democrats Favor Compromise") +
  scale_fill_brewer(palette="Blues") +
  theme(legend.position="none")

# 4
ggplot(world, aes(regime, urban, col=regime)) +
  geom_boxplot() +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  theme(axis.text.x = element_text(size=8, vjust=.7),
        legend.position="none") +
  ggtitle("Royal Dictatorships Favor Urban Populations") +
  ylab("Percentage of Population in Urban Areas") +
  xlab("") +
  coord_flip()

# 5

ggplot(world, aes(region, young, col=region)) +
  geom_boxplot() +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  theme(axis.text.x = element_text(size=8, vjust=.7),
        legend.position="none") +
  ggtitle("Youngest and Oldest Regions of the World") +
  ylab("Percentage of Population 0 to 21 Years Old") +
  xlab("") +
  coord_flip()

# 6 
ggplot(states, aes(region, knowgov, col=region)) +
  geom_boxplot() +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  theme(axis.text.x = element_text(size=8, vjust=.7),
        legend.position="none") +
  ggtitle("Northeast Most Knowledgeable") +
  ylab("Percentage of Respondents Who Knew Governor’s Name") +
  xlab("") +
  coord_flip()

# 7
ggplot(world, aes(pwthc, fdi)) +
  geom_point(col="#bf0000") +
             geom_text_repel(size=3, vjust=2, col="#263333", alpha = .3,
                             aes(label= iso3c)) +
               ggtitle("Question 7") +
               ylab("FDI") +
               xlab("Human Capital Index") +
               theme_minimal() +
               theme(plot.title = element_text(size = 8, face = "bold"),
                     axis.title = element_text(size = 8, face = "bold"))

# 8 
ggplot(states, aes(gunfree, murderrate)) +
  geom_point(col="#bf0000") +
             geom_text_repel(size=3, vjust=2, col="#263333", alpha = .3,
                             aes(label= st)) +
               ggtitle("Question 8") +
               ylab("Murder Rates") +
               xlab("Freedom of Gun Rights") +
               theme_minimal() +
               theme(plot.title = element_text(size = 8, face = "bold"),
                     axis.title = element_text(size = 8, face = "bold"))
# 9 
ggplot(states, aes(inc, turnout)) +
  geom_point(col="#bf0000") +
             geom_text_repel(size=3, vjust=2, col="#263333", alpha = .3,
                             aes(label= st)) +
               ggtitle("Question 9") +
               ylab("Turnout") +
               xlab("Median Income") +
               theme_minimal() +
               theme(plot.title = element_text(size = 8, face = "bold"),
                     axis.title = element_text(size = 8, face = "bold"))


# Chapter 11: Controlled Comparisons

# Code Chunk 11-1
nes$pid3.new <- ifelse(nes$pid3 == "Other", NA,
                       ifelse(nes$pid3 == "Not sure", NA,
                              nes$pid3))

nes$pid3.new <- as.factor(nes$pid3.new)

levels(nes$pid3.new)=c("Dem.", "Rep.", "Ind.")

nes$pid3.new = factor(nes$pid3.new,
                      levels(nes$pid3.new)[c(1,3,2)])


# Figure 11-1
ggplot(data = na.omit(nes[,c("pid3.new", "dpolice.new")])) +
  geom_mosaic(aes(x = product(pid3.new, dpolice.new),
                  fill=pid3.new,
                  na.rm=TRUE)) +
  guides(fill=guide_legend(title=NULL)) +
  ggtitle("Figure 11-1: Do Police Treat Whites and Blacks the Same?") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold"),
        axis.text.x=element_text(size = 8),
        axis.text.y=element_text(size = 8)) +
  scale_fill_brewer(palette="Blues") +
  xlab("") +
  ylab("") +
  theme(axis.text.x = element_text(size=8, vjust=.5),
        legend.position = "none") +
  coord_flip()


# Figure 11-2
nesmale <- subset(nes, nes$gender=="Male")
nesfemale <- subset(nes, nes$gender!="Male")

p1 <- ggplot(data =na.omit(nesmale[,
                                   c("pid3.new","dpolice.new")])) +
      geom_mosaic(aes(x = product(pid3.new, dpolice.new),
                  fill=pid3.new,na.rm=TRUE)) +
      guides(fill=guide_legend(title=NULL)) +
      ggtitle("Men") +
      xlab(label=NULL) +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
      scale_fill_brewer(palette="Blues") +
      theme(axis.text.x = element_text(size=8, vjust=.5),
        axis.text.y = element_text(size=8, vjust=.5),
        legend.position="none") +
      xlab("") +
      ylab("") +
      coord_flip()


p2 <- ggplot(data =na.omit(nesfemale[,
                                     c("pid3.new","dpolice.new")])) +
  geom_mosaic(aes(x = product(pid3.new, dpolice.new),
                  fill=pid3.new,na.rm=TRUE)) +
  guides(fill=guide_legend(title=NULL)) +
  ggtitle("Women") +
  xlab(label=NULL) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  scale_fill_brewer(palette="Blues") +
  theme(axis.text.x = element_text(size=8, vjust=.5),
        axis.text.y = element_text(size=8, vjust=.5),
        legend.position="none") +
  xlab("") +
  ylab("") +
  coord_flip()

grid.arrange(p1, p2, nrow=2, top=textGrob("Figure 11-2: 
                Men and Women Hold Similar Attitudes", gp=gpar(fontsize=8)))


# Figure 11-3
neswhite <- subset(nes, nes$race=="White")
nesnonwhite <- subset(nes, nes$gender!="White")

p1 <- ggplot(data=na.omit(neswhite[,
                                   c("pid3.new","dpolice.new")])) +
  geom_mosaic(aes(x = product(pid3.new, dpolice.new),
                  fill=pid3.new,na.rm=TRUE)) +
  guides(fill=guide_legend(title=NULL)) +
  ggtitle("Whites") +
  xlab(label=NULL) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  scale_fill_brewer(palette="Blues") +
  theme(axis.text.x = element_text(size=8, vjust=.5),
        axis.text.y = element_text(size=8, vjust=.5),
        legend.position = "none") +
  xlab("") +
  ylab("") +
  coord_flip()


p2 <- ggplot(data=na.omit(nesnonwhite[, c("pid3.new","dpolice.new")])) +
  geom_mosaic(aes(x = product(pid3.new, dpolice.new),
                  fill=pid3.new,na.rm=TRUE)) +
  guides(fill=guide_legend(title=NULL)) +
  ggtitle("Black, Latino, Asian") +
  xlab(label=NULL) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  scale_fill_brewer(palette="Blues") +
  theme(axis.text.x = element_text(size=8, vjust=.5),
        axis.text.y = element_text(size=8, vjust=.5),
        legend.position = "none") +
  xlab("") +
  ylab("") +
  coord_flip()


grid.arrange(p1, p2, nrow=2, top=textGrob("Figure 11-3: Do Police Favor Whites?", 
                                          gp=gpar(fontsize=8)))


# Figure 11-4
levels(nes$immig_numb)=c("Big increase", "Moderate increase",
                          "Small increase", "Same", "Small decrease",
                          "Moderate decrease", "Large decrease")

ggplot(data = subset(nes, nes$pid3.new!="NA")) +
  geom_mosaic(aes(x = product(pid3.new, immig_numb),
                  fill=pid3.new,
                  na.rm=TRUE)) +
  guides(fill=guide_legend(title=NULL)) +
  ggtitle("Figure 11-4: Democrats Favor More Immigration") +
  xlab("") +
  ylab("") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  scale_fill_brewer(palette="Blues") +
  theme(axis.text.x = element_text(size=8, vjust=.5),
        axis.text.y = element_text(size=8, vjust=.5),
        legend.position = "none") +
  coord_flip()

# Code Chunk 11-6
nes$college <- ifelse(nes$educ=="4-year", 1,
                      ifelse(nes$educ=="Post-graduate", 1, 0))

# Figure 11-5 


p1 <- ggplot(data = subset(nes, nes$pid3.new!="NA" & nes$college==1)) +
             geom_mosaic(aes(x = product(pid3.new, immig_numb),
                  fill=pid3.new,
                  na.rm=TRUE)) +
            guides(fill=guide_legend(title=NULL)) +
  ggtitle("College Educated") +
  xlab("") +
  ylab("") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face="bold"),
        axis.title = element_text(size = 8, face="bold")) +
  scale_fill_brewer(palette="Blues") +
  theme(axis.text.x = element_text(size=8, vjust=.5),
        axis.text.y = element_text(size=8, vjust=.5),
        legend.position = "none") +
  coord_flip()


p2 <- ggplot(data = subset(nes, nes$pid3.new!="NA" & nes$college!=1)) +
  geom_mosaic(aes(x = product(pid3.new, immig_numb),
                  fill=pid3.new,na.rm=TRUE)) +
  guides(fill=guide_legend(title=NULL)) +
  ggtitle("No College") +
  xlab("") +
  ylab("") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face="bold"),
        axis.title = element_text(size = 8, face="bold")) +
  scale_fill_brewer(palette="Blues") +
  theme(axis.text.x = element_text(size=7, vjust=.5),
        axis.text.y = element_text(size=7, vjust=.5),
        legend.position="none") +
  coord_flip()


grid.arrange(p1, p2, nrow=2,top=textGrob("Figure 11-5: Should Immigration Be Increased?", 
                                         gp=gpar(fontsize=8)))


# Figure 11-6 


p1 <- ggplot(data = subset(nes, nes$pid3.new!="NA" &
                             nes$employ=="Full-time")) +
  geom_mosaic(aes(x = product(pid3.new, immig_numb),
                  fill=pid3.new,na.rm=TRUE)) +
  guides(fill=guide_legend(title=NULL)) +
  ggtitle("Employed") +
  xlab(label=NULL) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face="bold"),
        axis.title = element_text(size = 8, face="bold")) +
  scale_fill_brewer(palette="Blues") +
  theme(axis.text.x = element_text(size=8, vjust=.5),
        axis.text.y = element_text(size=8, vjust=.5),
        legend.position = "none") +
  xlab("") +
  ylab("") +
  coord_flip()


p2 <- ggplot(data = subset(nes, nes$pid3.new!="NA" &
                             nes$employ!="Full-time")) +
  geom_mosaic(aes(x = product(pid3.new, immig_numb),
                  fill=pid3.new,na.rm=TRUE)) +
  guides(fill=guide_legend(title=NULL)) +
  ggtitle("Unemployed") +
  xlab(label=NULL) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face="bold"),
        axis.title = element_text(size = 8, face="bold")) +
  scale_fill_brewer(palette="Blues") +
  theme(axis.text.x = element_text(size=8, vjust=.5),
        axis.text.y = element_text(size=8, vjust=.5),
        legend.position = "none") +
  xlab("") +
  ylab("") +
  coord_flip()

grid.arrange(p1, p2, nrow=2, top=textGrob("Figure 11-6: 
            Employment Doesn’t Change the Relationship", gp=gpar(fontsize=8)))


# Figure 11-7


p1 <- ggplot(data = subset(nes, nes$pid3.new!="NA" &
                             nes$pew_churatd=="More than once a week")) +
  geom_mosaic(aes(x = product(pid3.new, immig_numb),
                  fill=pid3.new,na.rm=TRUE)) +
  guides(fill=guide_legend(title=NULL)) +
  ggtitle("More than once a week") +
  xlab("") +
  ylab("") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face="bold"),
        axis.title = element_text(size = 8, face="bold")) +
  scale_fill_brewer(palette="Blues") +
  theme(axis.text.x = element_text(size=8, vjust=.5),
        axis.text.y = element_text(size=8, vjust=.5),
        legend.position = "none") + coord_flip()


p2 <- ggplot(data = subset(nes, nes$pid3.new!="NA" &
                             nes$pew_churatd!="More than once a week")) +
  geom_mosaic(aes(x = product(pid3.new, immig_numb),
                  fill=pid3.new,na.rm=TRUE)) +
  guides(fill=guide_legend(title=NULL)) +
  ggtitle("Once a week or less") +
  xlab("") +
  ylab("") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face="bold"),
        axis.title = element_text(size = 8, face="bold")) +
  scale_fill_brewer(palette="Blues") +
  theme(axis.text.x = element_text(size=8, vjust=.5),
        axis.text.y = element_text(size=8, vjust=.5),
        legend.position = "none") +
  coord_flip()


grid.arrange(p1, p2, nrow=2, top=textGrob("Figure 11-7: 
            Church Attendance Changes the Relationship Between Party and Immigration", 
            gp=gpar(fontsize=8)))


# Figure 11-8
ggplot(world, aes(ethfrac, inf)) +
       geom_point(col="#bf0000") +
       geom_smooth(method="loess", se=FALSE, col="#0000ff") +
       theme_minimal() +
       theme(plot.title = element_text(size = 8, face = "bold"),
             plot.subtitle = element_text(size = 7),
             axis.title = element_text(size = 8, face="bold")) +
       xlab("Ethnolinguistic Fractionalization") +
       ylab("Female Infant Mortality Rate") +
       ggtitle(label = "Figure 11-8: Infant Mortality Increases as Ethnic Heterogeneity Increases", 
               subtitle = "Countries labeled are Haiti (HTI), Japan (JPN), United States (USA), Kenya (KEN), Equatorial Guinea (GNQ), Luxembourg (LUX), and Somalia (SOM)") +
       geom_text_repel(size=3, col="#04183d", aes(label=
                      ifelse(iso3c=="HTI" |
                             iso3c=="JPN" |
                             iso3c=="KEN" |
                             iso3c=="LSO" |
                             iso3c=="GNQ" |
                             iso3c=="LUX" |
                             iso3c=="SOM", as.character(iso3c),"")))

# Figure 11-9
world$gp <- ifelse(world$gdppc > 9863, 1, 0)
world$gp.f <- as.factor(world$gp)
levels(world$gp.f)=c("Low", "High")

ggplot(subset(world, gp.f!="NA"), aes(ethfrac, infemale, col=gp.f)) +
      geom_point() +
      geom_smooth(method="lm", se=FALSE) +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold"),
            axis.title = element_text(size = 8, face = "bold"),
            legend.title = element_text(size = 8, face = "bold")) +
      theme(legend.position = c(.6, .8)) +
      scale_color_manual(breaks = c("High", "Low"),
            values=c("#bf0000", "#0000ff")) +
      guides(col=guide_legend("GDP per capita")) +
      xlab("Ethnolinguistic Fractionalization") +
      ylab("Female Infant Mortality Rate") +
      ggtitle("Figure 11-9: It’s the Economy")

# Figure 11-10
ggplot(world, aes(log(gdppc), log(homicide))) +
        geom_point(col="#bf0000") +
        geom_smooth(se=FALSE, col="#0000ff") +
        ggtitle(label = "Figure 11-10: Homicides Rise and Fall as Income Increases",
                subtitle = "Countries labeled are Honduras (HND), El Salvador (SLV), United States (USA), \nTonga (TON), Czech Republic (CZE), and Sweden (SWE)") +
        ylab("Murder Rate") +
        xlab("GDP per Capita (logged)") +
        geom_text_repel(size=3, aes(label= ifelse(iso3c=="TON" |
                                                      iso3c=="USA" |
                                                      iso3c=="UT" |
                                                      iso3c=="HND" |
                                                      iso3c=="SLV" |
                                                      iso3c=="CZE" |
                                                      iso3c=="SWE",
                                                    as.character(iso3c), ''))) +
          theme_minimal() +
          theme(plot.title = element_text(size = 8, face = "bold"),
                axis.title = element_text(size = 8, face = "bold"),
                plot.subtitle = element_text(size = 7))
# Code Chunk 11-13
world$democ <- ifelse(world$polity2 > 7, 1, 0)
world$democ <- as.factor(world$democ)
levels(world$democ)=c("Dictatorship", "Democracy")

# Figure 11-11
ggplot(subset(world, democ!="NA"), aes(log(gdppc), log(homicide),
                                       col=democ)) +
  geom_point() +
  ggtitle("Figure 11-11: Democracy Matters With Murder and Income") +
  ylab("Murder Rate (logged)") +
  xlab("GDP per Capita (logged)") +
  geom_smooth(method="lm", se=FALSE) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold"),
        legend.title = element_text(size = 8, face = "bold")) +
  theme(legend.position = c(.3, .2)) +
  guides(col=guide_legend("Regime Type")) +
  scale_color_manual(breaks = c("Democracy", "Dictatorship"),
                     values=c("#bf0000", "#0000ff"))

# Answers

# 1

p1 <- ggplot(data = subset(nes, nes$pid3.new!="NA" &
                             nes$pew_churatd=="More than once a week")) +
  geom_mosaic(aes(x = product(pid3.new, compromise),
                  fill=pid3.new,na.rm=TRUE)) +
  guides(fill=guide_legend(title=NULL)) +
  ggtitle("Attends Church Often") +
  xlab("") +
  ylab("") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face="bold"),
        axis.title = element_text(size = 8, face="bold")) +
  scale_fill_brewer(palette="Blues") +
  theme(axis.text.x = element_text(size=8, vjust=.5),
        axis.text.y = element_text(size=8, vjust=.5),
        legend.position = "none") +
  coord_flip()


p2 <- ggplot(data = subset(nes, nes$pid3.new!="NA" &
                             nes$pew_churatd!="More than once a week")) +
  geom_mosaic(aes(x = product(pid3.new, compromise),
                  fill=pid3.new,na.rm=TRUE)) +
  guides(fill=guide_legend(title=NULL)) +
  ggtitle("Does Not Attend Church Often") +
  xlab("") +
  ylab("") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face="bold"),
        axis.title = element_text(size = 8, face="bold")) +
  scale_fill_brewer(palette="Blues") +
  theme(axis.text.x = element_text(size=7, vjust=.5),
        axis.text.y = element_text(size=7, vjust=.5),
        legend.position="none") +
  coord_flip()

grid.arrange(p1, p2, nrow=2,top=textGrob("Church Influences Republicans", gp=gpar(fontsize=8)))


# 2 
nes$hsgrad <- ifelse(nes$educ=="No HS", 0,
                     ifelse(nes$educ=="High school graduate", 0, 1))
nes$hsgrad.f <- as.factor(nes$hsgrad)
levels(nes$hsgrad.f)=c("No College", "At least some college")
nes$White <- ifelse(nes$race=="White", 1, 0)
nes$White.f <- as.factor(nes$White)
levels(nes$White.f)=c("Non-White", "White")
nes$married <- ifelse(nes$marstat=="Married", 1, 0)
nes$married.f <- as.factor(nes$married)
levels(nes$married.f)=c("Not married", "Married")


p1 <- ggplot(data = subset(nes, nes$White.f=="White")) +
      geom_mosaic(aes(x = product(hsgrad.f, married.f),
                  fill=hsgrad.f,na.rm=TRUE)) +
      guides(fill=guide_legend(title=NULL)) +
      ggtitle("White") +
      xlab("") +
      ylab("") +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face="bold"),
        axis.title = element_text(size = 8, face="bold")) +
      scale_fill_brewer(palette="Blues") +
      theme(axis.text.x = element_text(size=8, vjust=.5),
        axis.text.y = element_text(size=8, vjust=.5),
        legend.position = "none") +
      coord_flip()


p2 <- ggplot(data = subset(nes, nes$White.f!="White")) +
      geom_mosaic(aes(x = product(hsgrad.f, married.f),
                  fill=hsgrad.f,na.rm=TRUE)) +
      guides(fill=guide_legend(title=NULL)) +
      ggtitle("Non-white") +
      xlab("") +
      ylab("") +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face="bold"),
        axis.title = element_text(size = 8, face="bold")) +
      scale_fill_brewer(palette="Blues") +
      theme(axis.text.x = element_text(size=7, vjust=.5),
        axis.text.y = element_text(size=7, vjust=.5),
        legend.position="none") +
      coord_flip()

grid.arrange(p1, p2, nrow=2,top=textGrob("Race Doesn’t Influence Marriage and College", gp=gpar(fontsize=8)))

# 3
states$trumpwin.f <- as.factor(states$trumpwin)
levels(states$trumpwin.f)=c("Lost", "Won")

ggplot(states, aes(inc, percwom, col=trumpwin.f)) +
      geom_point() +
      geom_smooth(method="lm", se=FALSE) +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold"),
        legend.title = element_text(size = 8, face = "bold")) +
      theme(legend.position = c(.8, .2)) +
      scale_color_manual(breaks = c("Lost", "Won"),
                     values=c("#0000ff", "#bf0000")) +
                               guides(col=guide_legend("Trump’s Electoral Count")) +
                                 xlab("Median Household Income") +
                                 ylab("Ratio of Women’s Income to Men’s") +
                                 ggtitle("It’s the Economy")

# 4
ggplot(subset(world, democ!="NA"), aes(log(gdppc),turnout,col=democ)) +
      geom_point() +
      geom_smooth(method="lm", se=FALSE) +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold"), 
        legend.title = element_text(size = 8, face = "bold")) +
      theme(legend.position = c(.8, .1)) +
      scale_color_manual(values=c("#bf0000", "#0000ff")) +
                               guides(col=guide_legend("Regime Type")) +
                                 xlab("GDP per Capita (logged)") +
                                 ylab("Voter Turnout") +
                                 ggtitle("It’s the Economy")

# Practice on Analysis and Visualization

# 4
nes$newpolice <-ifelse(nes$disc_police=="Treats whites much better", 1,
                       ifelse(nes$disc_police=="Skipped", NA, 0))
nes$newpolice <- factor(nes$newpolice,
                        labels=c("Not Much Better", "Much Better"))

nes$newstop <- ifelse(nes$stop_ever=="Has happened", 1,
                      ifelse(nes$stop_ever=="Not asked", NA,
                             ifelse(nes$stop_ever=="Skipped", NA, 0)))

nes$newstop <-factor(nes$newstop, labels=c("Never Stopped", "Stopped"))


p1 <- ggplot(data = subset(nes, nes$newstop!="NA" &
                             nes$White.f=="White")) +
  geom_mosaic(aes(x = product(newpolice, newstop),
                  fill=newpolice,na.rm=TRUE)) +
  guides(fill=guide_legend(title=NULL)) +
  ggtitle("White") +
  xlab(label=NULL) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face="bold"),
        axis.title = element_text(size = 8, face="bold")) +
  scale_fill_brewer(palette="Blues") +
  theme(axis.text.x = element_text(size=8, vjust=.5),
        axis.text.y = element_text(size=8, vjust=.5),
        legend.position = "none") +
  xlab("") +
  ylab("") +
  coord_flip()


p2 <- ggplot(data = subset(nes, nes$newstop!="NA" & nes$newpolice!="NA"
                           & nes$White!="White")) +
  geom_mosaic(aes(x = product(newpolice, newstop),
                  fill=newpolice, na.rm=TRUE)) +
  guides(fill=guide_legend(title=NULL)) +
  ggtitle("non-White") +
  xlab(label=NULL) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face="bold"),
        axis.title = element_text(size = 8, face="bold")) +
  scale_fill_brewer(palette="Blues") +
  theme(axis.text.x = element_text(size=8, vjust=.5),
        axis.text.y = element_text(size=8, vjust=.5),
        legend.position = "none") +
  xlab("") +
  ylab("") +
  coord_flip()

grid.arrange(p1, p2, nrow=2, top=textGrob("", gp=gpar(fontsize=8)))


# 5 
nes$newcause <- ifelse(nes$warmcause=="Mostly by human activity", 1, 0)
nes$newcause <- factor(nes$newcause,
                       labels=c("Natural Cause", "Man-made"))
nes$newchurch <- ifelse(nes$pew_churatd=="More than once a week", 1,
                        ifelse(nes$pew_churatd=="Once a week", 1,
                               ifelse(nes$pew_churatd=="Skipped", NA, 0)))
nes$newchurch <- factor(nes$newchurch,
                        labels=c("Not more than once a week",
                                  "More than once a week"))


p1 <-ggplot(data=subset(nes, nes$newchurch=="More than once a week")) +
  geom_mosaic(aes(x = product(newcause, educ),
                  fill=newcause,na.rm=TRUE)) +
  guides(fill=guide_legend(title=NULL)) +
  ggtitle("Frequent Church Attendance") +
  xlab(label=NULL) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face="bold"),
        axis.title = element_text(size = 8, face="bold")) +
  scale_fill_brewer(palette="Blues") +
  theme(axis.text.x = element_text(size=8, vjust=.5),
        axis.text.y = element_text(size=8, vjust=.5),
        legend.position = "none") +
  xlab("") +
  ylab("") +
  coord_flip()


p2 <- ggplot(data = subset(nes, nes$newcause!="NA" &
                             nes$newchurch!="More than once a week")) +
  geom_mosaic(aes(x = product(newcause, educ),
                  fill=newcause, na.rm=TRUE)) +
  guides(fill=guide_legend(title=NULL)) +
  ggtitle("Non-Frequent") +
  xlab(label=NULL) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face="bold"),
        axis.title = element_text(size = 8, face="bold")) +
  scale_fill_brewer(palette="Blues") +
  theme(axis.text.x = element_text(size=8, vjust=.5),
        axis.text.y = element_text(size=8, vjust=.5),
        legend.position = "none") +
  xlab("") +
  ylab("") +
  coord_flip()

grid.arrange(p1, p2, nrow=2, top=textGrob("", gp=gpar(fontsize=8)))


# 6 
states$rich <- cut(states$inc, breaks=c(0,40000,60000))
states$rich <- factor(states$rich, labels = c("Poor", "Rich"))

ggplot(states, aes(stuspend, murderrate, col=rich)) +
  geom_point() +
  ggtitle("Murder, Income, and Education Spending") +
  ylab("Homicides") +
  xlab("Spending per Student") +
  geom_smooth(method="lm", se=FALSE) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold"),
        legend.title = element_text(size = 8, face = "bold")) +
  theme(legend.position = c(.5, .8)) +
  guides(col=guide_legend("Wealth")) +
  scale_color_manual(breaks = c("Poor", "Rich"),
                     values=c("#bf0000", "#0000ff"))

# 7 
ggplot(subset(world, democ!="NA"), aes(log(gdppc), log(fdi), col=democ)) +
  geom_point() +
  ggtitle("Income, FDI, and Democracy") +
  ylab("FDI") +
  xlab("GDP per Capita (logged)") +
  geom_smooth(method="lm", se=FALSE) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold"),
        legend.title = element_text(size = 8, face = "bold")) +
  theme(legend.position = c(.4, .9)) +
  guides(col=guide_legend("Regime Type")) +
  scale_color_manual(breaks = c("Dictatorship", "Democracy"),
                     values=c("#bf0000", "#0000ff"))

# 8 
ggplot(subset(world, democ!="NA"), aes(ethfrac, log(gdppc), col=democ)) +
  geom_point() +
  ggtitle("Ethnicity, Income, and Democracy") +
  ylab("GDP per Capita (logged)") +
  xlab("Ethnolinguistic Fractionalization") +
  geom_smooth(method="lm", se=FALSE) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold"),
        legend.title = element_text(size = 8, face = "bold")) +
  theme(legend.position = c(.9, .9)) +
  guides(col=guide_legend("Regime Type")) +
  scale_color_manual(breaks = c("Dictatorship", "Democracy"),
                     values=c("#bf0000", "#0000ff"))

# 9 
world$women3 <- cut(world$womleg, breaks=c(0,10,18,57))
world$women3 <- factor(world$women3, labels = c("low", "medium", "high"))
#world$britcol <- ifelse(world$colony=="UK", 1, 0)
#world$britcol <- factor(world$britcol, labels=c("No British legacy", "British Legacy"))

ggplot(subset(world, women3!="NA"), aes(log(gdppc), infemale, col=women3)) +
  geom_point() +
  ggtitle("Women in the Legislature and Infant Health") +
  ylab("Infant Mortality for Girls") +
  xlab("GDP per Capita (logged)") +
  geom_smooth(method="lm", se=FALSE) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold"),
  #theme(legend.position = c(.9, .9)) +
        legend.title = element_text(size = 8, face = "bold")) #+
  #guides(col=guide_legend("Level of Women's Representation")) +
  #scale_color_manual(breaks = c("Low", "Medium", "High"),
                    #values=c("#bf0000", "#0000ff", "#00bf00"))


# 10 
ggplot(states, aes(hsdiploma, democrat, col=region)) +
  geom_point() +
  ggtitle("Education and Voting") +
  ylab("Percentage of the Electorate Identifying as Democrat") +
  xlab("Percentage of the Adult Population With High School Degrees") +
  geom_smooth(method="lm", se=FALSE) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  theme(legend.position = c(.9, .9)) +
  guides(col=guide_legend("Region")) +
  scale_color_manual(values=c("#bf0000", "#0000ff", "#00bf00", "#0000bf"))


# Chapter 12: Linear Regression

# Figure 12-1
states$turnperc <- states$turnout * 100

ggplot(states, aes(hsdiploma, turnperc)) +
        geom_text_repel(size = 3, aes(label = st,
                        size = 1, hjust = 0, vjust = -1),
                        col = ifelse(states$st == "MN", "#0000bf",
                              ifelse(states$st == "HI", "#0000bf",
                                      "white"))) +
        geom_smooth(method = "lm", se = FALSE, size = 0.25) +
        xlab("Percent With High School Diploma") + ylab("Voter Turnout") +
        ggtitle("Figure 12-1: Turnout and Education") +
        geom_point(col = "#bf0000", size = 0.8) +
        theme_minimal() +
        theme(plot.title = element_text(size = 8, face = "bold"),
              axis.title = element_text(size = 8, face = "bold"))

# Table 12-1
ed.lm <- lm(turnperc ~ hsdiploma, data = states)

stargazer(ed.lm, title = "Table 12-1: Turnout and Education",
          type = "text", textheader = FALSE)

# Figure 12-2
ggplot(states, aes(hsdiploma, turnperc)) +
  geom_point(col = "grey") + geom_text_repel(size = 3,
                                             aes(label = st, size = 1, vjust = 1),
                                             col = ifelse(states$st == "MN", "black", "white")) +
  geom_smooth(method = "lm", se = FALSE) +
  labs(x = "Percent With High School Diploma", y = "Voter Turnout",
       title = "Figure 12-2: Anatomy of a Line") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  annotate("text", x = 85, y = 70, parse = T,
            label = "Residual~or~error~e==Y[i]~-~hat(Y[i])",
            size = 3) +
  annotate("text", x = 82, y = 67, parse = T,
            label = "'Equation for the line'~hat(Y[i])==a~+~beta[i]~x[i]", size = 3) +
  annotate("text", x = 89, y = 76, parse = T,
            label = "Y[i]") +
  annotate("text", x = 89, y = 64.5, parse = T,
            label = "~hat(Y[i])") +
  annotate("segment", x = 89, xend = 90.76, y = 64.3,
            yend = 64.3, size = 0.2) +
  annotate("segment", x = 87.3, xend = 90.76, y = 69.7,
            yend = 69.7, size = 0.2) +
  annotate("segment", x = 89.2, xend = 90.76, y = 76,
            yend = 76, size = 0.2) +
  annotate("segment", x = 82, xend = 82, y = 65.5,
            yend = 58, size = 0.2) +
  annotate("segment", x = 90.76, xend = 90.76, y = 76,
            yend = 64.5, col = "#bf0000", linetype = "dashed")

# Figure 12-13
ggplot(states, aes(hsdiploma, turnperc)) +
  geom_text(size = 3, aes(label = st, size = 1, vjust = 0.8,
                          hjust = 1.2), col = ifelse(states$st == "MN", "black",
                                                     ifelse(states$st == "ME", "black", "white"))) +
  geom_smooth(method = "lm", se = FALSE) +
  labs(x = "Percent With High School Diploma", y = "Voter Turnout",
       title = "Figure 12-3: Goodness of Fit") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  geom_hline(yintercept = 59, linetype = 3) +
  geom_point(col = "lightgrey") +
  annotate("segment", x = 88.4, xend = 90.76, y = 69, yend = 69,
            size = 0.2, col = "#bf0000") +
            annotate("text", x = 87.4, y = 69, parse = T,
                      label = "'Unexplained deviation'",
                      size = 3, col = "#bf0000") +
                      annotate("text", x = 88, y = 61, col = "#0000bf", parse = T,
                                label = "'Explained deviation'", size = 3) +
                        annotate("text", x = 92.5, y = 67, parse = T,
                                  label = "'Total deviation'", size = 3) +
                        annotate("text", x = 94, y = 60, parse = T,
                                  label = "~bar(Y)==59") +
                        xlim(85, 95) +
                        annotate("segment", x = 90.76, xend = 90.76, y = 76,
                                  yend = 63, col = "#bf0000", size = 0.2,
                                  linetype = "dashed") +
                        annotate("segment", x = 90.76, xend = 90.76, y = 63,
                                  yend = 59, col = "#0000bf", size = 0.2,
                                  linetype = "dashed") +
                        annotate("segment", x = 91, xend = 91, y = 76, yend = 59,
                                  size = 0.5, linetype = "dashed") +
                        annotate("segment", x = 88.85, xend = 90.76, y = 61, yend = 61,
                                  size = 0.2, col = "#0000bf") +
                                  annotate("segment", x = 91, xend = 91.8, y = 67,
                                            yend = 67, size = 0.2)


# Code Chunk 12-5
sd30 <- rnorm(100, mean = 50, sd = 30)
sd5 <- rnorm(100, mean = 50, sd = 5)
xvar <- 1:100
Y1 <- 5 + 0.78 * xvar + sd30
Y2 <- 5 + 0.78 * xvar + sd5

# Figure 12-4
p1 <- ggplot(, aes(xvar, Y1)) +
      geom_point(col = "#bf0000", size = 0.5) +
      geom_smooth(method = "lm", se = FALSE, size = 0.5) +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold"),
        plot.subtitle = element_text(size = 8, face = "bold")) +
      labs(subtitle = expression(R^2 == .43), y = NULL, x = NULL) +
      ylim(0, 200)

p2 <- ggplot(, aes(xvar, Y2)) +
      geom_point(col = "#bf0000", size = 0.5) +
      geom_smooth(method = "lm", se = FALSE, size = 0.5) +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold"),
        plot.subtitle = element_text(size = 8, face = "bold")) +
      labs(subtitle = expression(R^2 == .95), y = NULL, x = NULL) +
      ylim(0, 200)

grid.arrange(p1, p2, ncol = 2, top = textGrob("Figure 12-4:Comparison of R-Square Statistics", gp = gpar(fontsize = 8)))


# Table 12-2
abort.lm <- lm(abort ~ evangel, data = states)
stargazer(abort.lm, type = "text", main = "Table 12-2:Evangelism Discourages Abortions", header = FALSE)

# Figure 12-5
ggplot(states, aes(evangel, abort)) +
      geom_point(col = "#bf0000") +
      geom_text(size = 3, aes(label = st, size = 1,
                      hjust = 0, vjust = -1), col = "grey",show.legend = FALSE) +
       ggtitle("Figure 12-5: Religion Reduces Abortion") +
       geom_smooth(method = "lm", se = F, fullrange = F,
                   col = "#0000bf") +
       theme_minimal() +
       theme(plot.title = element_text(size = 8, face = "bold"),
             axis.title = element_text(size = 8, face = "bold")) +
       ylab("Abortions per 1,000 Women") +
       xlab("Percent of Population That Is Evangelical")

# Table 12-3
gun.lm <- lm(gunfree ~ evangel, data = states)
stargazer(gun.lm, type = "text", main = "Table 12-3: Religiosity is related to Gun Laws", header = FALSE)

# Figure 12-6
ggplot(states, aes(evangel, gunfree)) +
      geom_point(col = "#bf0000") +
      geom_text(size = 3, aes(label = st, size = 1,
                      hjust = 0, vjust = -1), col = "grey",show.legend = FALSE) +
      ggtitle("Figure 12-6: Religion Bolsters Gun Freedom") +
      geom_smooth(method = "lm", se = F, fullrange = F) +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
      ylab("Gun Freedom Index") +
      xlab("Percent of Population that is Evangelical")

# Table 12-4
world$elf <- world$ethfrac * 100
murder.lm <- lm(log(homicide + 1) ~ elf, data = world)

stargazer(murder.lm, type = "text", title = "Table 12-4: Ethnic Heterogeneity and Violence Are Related", header = FALSE)

# Figure 12-7
ggplot(world, aes(elf, log(homicide + 1))) +
      geom_point(col = "#bf0000") +
      geom_text_repel(size = 3, aes(label =
                      ifelse(iso3c %in% c("USA", "HND", "AFG", "DEU"),
                                                    as.character(country), ""),
                      size = 1, hjust = 0, vjust = 1), col = "grey",
                             show.legend = FALSE) +
      ggtitle("Figure 12-7: Heterogeneous Populations Spur Homicide") +
      geom_smooth(method ="lm", se = F,fullrange = F,col = "#0000bf") +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold"),
            axis.title = element_text(size = 8, face = "bold")) +
      ylab("Homicides per 100,000 People") +
      xlab("Ethnolinguistic Fractionalization")

# Table 12-5
violence.lm <- lm(log(durable + 1) ~ log(homicide + 1), data = world)

stargazer(violence.lm, type = "text", title = "Table 12-5: Political Stability and Homicide", header = FALSE)

# Figure 12-8
ggplot(world, aes(log(homicide + 1), log(durable + 1))) +
        geom_point(col = "#bf0000") +
        geom_text(size = 3, aes(label =
                        ifelse(iso3c %in% c("USA", "HND", "AFG", "SWE"),
                        as.character(country), ""), size = 1, hjust = 1,
                        vjust = 1), col = "grey", show.legend = FALSE) +
        ggtitle("Figure 12-8: Murder Has Little Effect") +
        geom_smooth(method = "lm",se = F, fullrange = F,col= "#0000bf") +
        theme_minimal() +
        theme(plot.title = element_text(size = 8, face = "bold"),
              axis.title = element_text(size = 8, face = "bold")) +
        ylab("Years Since Significant Regime Change (logged)") +
        xlab("Homicide Rate (logged)")

# Table 12-6
wealth.lm <- lm(turnout ~ log2(gdppc), data = world)

stargazer(wealth.lm, type = "text", title = "Table 12-6: Income’s Meek Influence on Turnout", header = FALSE)

# Figure 12-9
ggplot(world, aes(log2(gdppc), turnout)) +
      geom_point(col = "#bf0000") +
      geom_text_repel(size = 3, aes(label =
                     ifelse(iso3c %in% c("USA", "LUX", "RWA", "HTI"),
                     as.character(country), ""), size = 1,
                     hjust = 0, vjust = 1), col = "grey", show.legend = FALSE) +
      ggtitle("Figure 12-9: Income Can’t Move Turnout") +
      geom_smooth(method = "lm", se = F, fullrange = F) +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold"),
            axis.title = element_text(size = 8, face = "bold")) +
      ylab("Voter Turnout") +
      xlab("GDP per Capita (logged)")

# Answers

# 7 
income.lm <- lm(inc ~ hsdiploma, data = states)

stargazer(income.lm, type = "text", title ="Education Increases Income", header = FALSE)
          
ggplot(states, aes(hsdiploma, inc)) +
       geom_point(col = "#bf0000") +
       ggtitle("Income and Education in the United States") +
       geom_smooth(method = "lm", se = F, fullrange = F,
                   col = "#0000bf") +
       theme_minimal() +
       theme(plot.title = element_text(size = 8, face = "bold"),
             axis.title = element_text(size = 8, face = "bold")) +
       ylab("Median per Capita Income") +
       xlab("Percentage of Population With High School Education")

# 8 
develop.lm <- lm(log(durable + 1) ~ log(gdppc), data = world)

stargazer(develop.lm, type = "text", title = "Political Stability and Income", header = FALSE)

ggplot(world, aes(log(durable + 1), log(gdppc))) +
      geom_point(col = "#bf0000") +
      ggtitle("Political Stability and Income") +
      geom_smooth(method = "lm", se = F, fullrange = F,
                  col = "#0000bf") +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold"),
            axis.title = element_text(size = 8, face = "bold")) +
      ylab("GDP per Capita (logged)") +
      xlab("Number of Years Since Political Change (logged)")

# 9 
murder.lm <- lm(murderrate ~ stuspend, data = states)

stargazer(murder.lm, type = "text", title = "Spend on Students to Save on Police", header = FALSE)

ggplot(states, aes(stuspend, murderrate)) +
      geom_point(col = "#bf0000") +
      ggtitle("Murder and Education in the United States") +
      geom_smooth(method = "lm", se = F, fullrange = F,
                  col = "#0000bf") +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold"),
      axis.title = element_text(size = 8, face = "bold")) +
      ylab("Homicide Rate") +
      xlab("Dollars per Student")

# 10
youth.lm <- lm(log(homicide) ~ young, data = world)

stargazer(youth.lm, type = "text", title = "Youth and Homicide", header = FALSE)

ggplot(world, aes(young, log(homicide))) +
      geom_point(col = "#bf0000") +
      ggtitle("Youth Kills") +
      geom_smooth(method = "lm", se = F, fullrange = F,
                  col = "#0000bf") +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold"),
            axis.title = element_text(size = 8, face = "bold")) +
      ylab("Homicide (murders per 100,000; logged)") +
      xlab("Percentage of Population Between 0 and 14 Years")


# Chapter 13: Multiple Regression

# Table 13-1
abort1 <-lm(abort~hsdiploma + evangel + density + inc, data=states)
abort2 <-lm(abort~hsdiploma + evangel + density, data=states)
abort3 <-lm(abort~hsdiploma + evangel, data=states)
abort4 <-lm(abort~hsdiploma, data=states)

stargazer(abort1, abort2, abort3, abort4, type = "text",
          title = "Table 13-1: Different Specifications of the Abortion Rate Model",
          header=FALSE, omit.stat = c("ser", "f"))

# Figure 13-2
ggplot(states, aes(murderrate)) +
        geom_histogram(bins=6, colour = "#0000bf", fill = "white") +
        ggtitle("Figure 13-2: Histogram of Murder") +
        xlab("Homicides per 100,0000") +
        ylab("Count") +
        theme_minimal() +
        theme(plot.title = element_text(size = 8, face = "bold"),
              axis.title = element_text(size = 8, face = "bold"))
# Figure 13-3
ggplot(states, aes(hsdiploma, murderrate)) +
      geom_point(col="#bf0000") +
      geom_text(size=3, aes(label = st, size = 1,
                      hjust = 0, vjust=-1),col="grey", show.legend=FALSE) +
      ggtitle("Figure 13-3: Education Prevents Murder") +
      geom_smooth(method="lm", se=F, fullrange=F, col="#0000bf") +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold"),
            axis.title = element_text(size = 8, face = "bold")) +
      ylab("Homicides per 100,0000") +
      xlab("Percentage of Population With High School Diploma")

# Figure 13-4
ggplot(states, aes(medinc, murderrate)) + 
  geom_point(col="#bf0000") +
  geom_text(size=3, aes(label = st, size = 1,
                  hjust = 0, vjust=-1),col="grey", show.legend=FALSE) +
  ggtitle("Figure 13-4: Wealth and Violence Don’t Mix") +
  geom_smooth(method="lm", se=F, fullrange=F, col="#0000bf") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  ylab("Homicides per 100,0000") +
  xlab("Median Household Income")

# Figure 13-5
ggplot(states, aes(density, murderrate)) + 
  geom_point(col="#bf0000") +
  geom_text(size=3, aes(label = st, size = 1, hjust = 0,
                  vjust=-1), col="grey", show.legend=FALSE) +
  ggtitle("Figure 13-5: Homicides Happen in Crowded Places") +
  geom_smooth(method="lm", se=F, fullrange=F, col="#0000bf") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  ylab("Homicides per 100,0000") +
  xlab("Person per Square Mile")

# Figure 13-6
h1 <- ggplot(states, aes(density)) +
      geom_histogram(bins=6, colour = "#0000bf", fill = "white") +
      ggtitle("Raw Form") +
      xlab("People per Square Mile") +
      ylab("Count") +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold"),
            axis.title = element_text(size = 8, face = "bold"))

h2 <- ggplot(states, aes(log2(density))) +
      geom_histogram(bins=6, colour = "#0000bf", fill = "white") +
      ggtitle("Logged Form") +
      xlab("People per Square Mile (logged)") +
      ylab("Count") +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold"),
            axis.title = element_text(size = 8, face = "bold"))


grid.arrange(h1, h2, ncol=2, top=textGrob("Figure 13-6: Raw and Logged Form of Density", gp=gpar(fontsize=8)))

# Table 13-2
murder.lm <- lm(murderrate ~ medinc + hsdiploma + density, data=states)
murder1.lm <- lm(murderrate ~ medinc + hsdiploma + log2(density), data=states)

stargazer(murder.lm, murder1.lm, title = "Table 13-2: Logging Density and Its Impact on Regression Results", type = "text", header=FALSE)

# Figure 13-7
ggplot(states, aes(hsdiploma, raperate)) +
        geom_point(col="#bf0000") +
        geom_text_repel(size=3, aes(label = st, size = 1,
                        hjust = 0, vjust=-1), col="grey", show.legend=FALSE) +
        labs(title = paste("Figure 13-7: Education Increases Rape Rate")) +
        geom_smooth(method="lm", se=F, fullrange=F, col="#0000bf") +
        theme_minimal() +
        theme(plot.title = element_text(size = 8, face = "bold"),
              axis.title = element_text(size = 8, face = "bold")) +
        ylab("Reported Incidents of Rape per 100,0000 Population") +
        xlab("Percentage of Population With High School Diploma")

ggplot(states, aes(log2(density), raperate)) +
        geom_point(col="#bf0000") +
        geom_text(size=3, aes(label = st, size = 1,
                        hjust = 0, vjust=-1), col="grey", show.legend=FALSE) +
        labs(title = paste("Figure 13-8: Population Density and Rape Rate")) +
        geom_smooth(method="lm", se=F, fullrange=F, col="#0000bf") +
        theme_minimal() +
        theme(plot.title = element_text(size = 8, face = "bold"),
              axis.title = element_text(size = 8, face = "bold")) +
        ylab("Reported Rapes per 100,000 population") +
        xlab("People per square mile")           

# Table 13-3 
rape.lm <- lm(raperate ~ medinc + hsdiploma + log2(density), data=states)

stargazer(rape.lm, title = "Table 13-3: Rape Rate Regressed on Education", type = "text", header=FALSE)

# Practice on Analysis and Visualization 

# 3
summary(lm(inf ~ turnout + log2(gdppc), data=world))

# 4 
summary(lm(hsdiploma ~ inc + infant + democrat, data=states))

# 5 
summary(lm(gtbeduc ~ womyear + log(gdppc), data=world))

# 6
summary(lm((infemale/infmale)*100 ~ womyear + log(gdppc), data = world))

# 7 
wout.lm <- lm(inc ~ hsdiploma + poptotal + stuspend, data = states)
with.lm <- lm(inc ~ hsdiploma + poptotal + stuspend + democrat, data = states)

stargazer(wout.lm, with.lm, header=FALSE, type="text", title = "Party Identification Is Relatively Inconsequential")

# 8 
summary(lm(log(co2) ~ young + log(gdppc), data=world ))

# 9 
without.lm <- lm(hsdiploma ~ inc + infant + democrat, data = subset(states, st!="NY" & st!="CA" & st!="NJ"))
withall.lm <- lm(hsdiploma ~ inc + infant + democrat, data = states)

stargazer(without.lm, withall.lm, header=FALSE, type="text", title = "Absences of Cases Changes Results")

# 10 
woutME.lm <- lm(gtbeduc*100 ~ womyear + log(gdppc), data=subset(world, region!="ME and North Africa"))
withME.lm <- lm(gtbeduc*100 ~ womyear + log(gdppc), data=world)

stargazer(woutME.lm, withME.lm, header=FALSE, type = "text", title =
            "Including the Middle Eastern Cases Makes Little Difference")

# Chapter 14: Dummies and Interaction

# Table 14-1
genmus1 <- lm(ftmuslim ~ 1, data=nes)
genmus2 <- lm(ftmuslim ~ gender, data=nes)

stargazer(genmus1, genmus2, type = "text",
          title = "Table 14-1: Women View Muslims More Positively",
          header=FALSE)

# Table 14-2
nes$educ.n <- as.numeric(nes$educ)
nes$pid7.n <- as.numeric(nes$pid7)

muslim.lm <- lm(ftmuslim ~ gender + educ.n + pid7.n, data=nes)

stargazer(muslim.lm,
          title = "Table 14-2: Gender Influences Attitudes Toward Muslims",
          header = FALSE, type="text")

# Code Chunk 14-3
nes$pid3.new <- ifelse(nes$pid3 == "Other", NA,
                ifelse(nes$pid3 == "Not sure", NA, nes$pid3))

nes$pid3.new <- as.factor(nes$pid3.new)

levels(nes$pid3.new)=c("Democrat", "Republican", "Independent")

nes$pid3.new = factor(nes$pid3.new, levels(nes$pid3.new)[c(1,3,2)])

# Table 14-3
muslim3.lm <- lm(ftmuslim ~ gender, data=nes)
muslim4.lm <- lm(ftmuslim ~ gender + pid3.new, data=nes)

stargazer(muslim3.lm, muslim4.lm, type = "text",
          title = "Table 14-3: Views Toward Muslims", header = FALSE)

# Code Chunk 14-5
nes$nfam <- nes$faminc
nes$nfam[nes$nfam > 16] <- NA
nes$educ.n <- as.numeric(nes$educ)

# Figure 14-2
ggplot(nes, aes(educ.n, nfam, col=gender)) +
      geom_smooth(method="lm", se=FALSE) +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold"),
            axis.title = element_text(size = 8, face = "bold"),
            legend.title = element_text(size = 10, face = "bold"),
       legend.position = c(.8,.3)) +
       scale_color_manual(values = c("#0000bf", "#bf0000"), "Gender") +
       ggtitle("Figure 14-2: Interaction Between Education and Gender") +
       ylab("Income (ordinal scale)") +
       xlab("Education Level (ordinal scale)")

# Code Chunk 14-7
nes$college <- nes$educ
nes$college <- ifelse(nes$college=="4-year", 1,
               ifelse(nes$college=="Post-grad", 1, 0))
nes$inc <- nes$faminc
nes$inc <- ifelse(nes$inc > 16, NA, nes$inc)
nes$inc.n <- as.numeric(nes$inc)

# Table 14-4
sanders <- lm(ftsanders ~ inc.n + college + inc.n:college, data=nes)
stargazer(sanders, title = "Table 14-4: Income, Education, and Bernie",
          header = FALSE, type = "text")

# Figure 14-3

interact_plot(sanders, pred = inc.n, modx = college,
              legend.main = "College Graduate",
              modx.labels = c("no", "yes")) +
  ylim(20,80) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold"),
        legend.title = element_text(size = 10, face = "bold"),
        legend.position = c(.3,.3)) +
  annotate("segment", x = 12, xend = 12, y = 65, yend = 55,size = .2) +
  annotate("text", x = 12, y = 67, parse = F,
            label = 'Slope = .59', size = 3) +
  annotate("segment", x = 14, xend = 14, y = 49, yend = 40, size =.2) +
  annotate("text", x = 14, y = 37, parse = F,
            label = 'Slope = .59 - .719', size = 3) +
  annotate("segment", x = 1, xend = 1, y = 48, yend = 58, size = .2) +
  annotate("text", x = 4, y = 60, parse = F,
  label = 'When x = 0, the difference between \n the intercepts is 3.24', size = 3) +
  ggtitle("Figure 14-3: Interaction Between Education and Income") +
  ylab("Feeling Thermometer for Bernie Sanders") +
  xlab("Income (ordinal scale)")

# 14-4
interact_plot(sanders, pred = inc.n, modx = college,
              interval = TRUE, int.width = .95,
              legend.main = "College Graduate",
              modx.labels = c("no", "yes")) +
  ylim(20,80) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold"),
        legend.title = element_text(size = 8, face = "bold"),
        legend.position = c(.3,.3)) +
  ggtitle("Figure 14-4: Confidence Bands Overlap") +
  ylab("Feeling Thermometer for Bernie Sanders") +
  xlab("Income (ordinal scale)")

# Code Chunk 14-11
world$lnaid <- log(world$aid +1)
world$lngdppc <- log(world$gdppc)
world$dem <- ifelse(world$regime=="Parliamentary Democracy", 1,
                    ifelse(world$regime=="Presidential Democracy", 1, 0))
world$dem <- as.factor(world$dem)
levels(world$dem)=c("Dictatorship", "Democracy")

# Table 14-5
aid.lm <- lm(lnaid ~ lngdppc * dem + log(durable + 1) + ethfrac, data=world)
stargazer(aid.lm, title = "Table 14-5: Democracy Interacts With Income", header = FALSE, type = "text")

# Figure 14-5
interact_plot(aid.lm, pred = lngdppc, modx = dem, data = world,
              legend.main = "Regime Type",
              modx.labels = c("Dictatorship", "Democracy"),
              plot.points = TRUE,
              colors = c("#bf0000", "#0000bf")) +
                          xlab("GDP per Capita (logged)") +
                            ylab("Aid as a Percentage of GDP (logged)") +
                            ggtitle("Figure 14-5: Interaction Between Democracy and GDP per Capita") +
                            theme_minimal() +
                            theme(plot.title = element_text(size = 8, face = "bold"),
                                  axis.title = element_text(size = 8, face = "bold"),
                                  legend.title = element_text(size = 8, face = "bold"),
                                  legend.position = c(.8,.8))

# Practice on Analysis and Visualization

# 9 
mod1.lm <- lm(lngdppc ~ ethfrac + dem + ethfrac:dem, data=world)

interact_plot(mod1.lm, pred = ethfrac, modx = dem, data = world,
              legend.main = "Regime Type",
              modx.labels = c("Dictatorship", "Democracy"),
              plot.points = TRUE,
              colors = c("#bf0000", "#0000bf")) +
                          xlab("Ethnolinguistic Fractionalization") +
                            ylab("GDP per Capita (logged)") +
                            ggtitle("Interaction Between Democracy and ELF") +
                            theme_minimal() +
                            theme(plot.title = element_text(size = 8, face = "bold"),
                                  axis.title = element_text(size = 8, face = "bold"),
                                  legend.title = element_text(size = 8, face = "bold"),
                                  legend.position = c(.9,.9))


# 10

mod2.lm <- lm(murderrate ~ weed + inc + weed:inc, data=states)

interact_plot(mod2.lm, pred = inc, modx = weed, data =states,
              legend.main = "Marijuana Laws",
              modx.labels = c("Not Legal", "Legal"),
              plot.points = TRUE,
              colors = c("#bf0000", "#0000bf")) +
                          xlab("Income per capita") +
                            ylab("Homicide Rate (murders per 100,000)") +
                            ggtitle("Interaction Between Marijuana Laws and Income") +
                            theme_minimal() +
                            theme(plot.title = element_text(size = 8, face = "bold"),
                                  axis.title = element_text(size = 8, face = "bold"),
                                  legend.title = element_text(size = 10),
                                  legend.position = c(.9,.9))

# Chapter 15: Diagnostics I: Is Ordinary Least Squares Appropriate? 

# Code Chunk 15-1
x <- data.frame(Unbiased=rnorm(1000000,0,1),
                Biased=rnorm(1000000,1,1),
                Efficient=rnorm(1000000,0,.5))

data<- melt(x, id.vars = NULL)

# Figure 15-1
ggplot(data,aes(x=value, fill=variable)) +
  geom_density(alpha=0.50) +
  ggtitle("Figure 15-1: Properties of Estimators") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold"),
        legend.position = c(.8,.6)) +
  scale_fill_discrete(name = "Estimator",
                      labels = c("Unbiased", "Biased", "Efficient"))

# Code Chunk 15-3
set.seed(3376)
min=-40; max=40; n=5
xbar1=rep(0,1000000)
for (i in 1:1000000) {xbar1[i]= mean(runif(n, min, max))}

x1 <- data.frame(v1=xbar1)

set.seed(3376)
min=-40; max=40; n=25
xbar2=rep(0,1000000)
for (i in 1:1000000) {xbar2[i]= mean(runif(n, min, max))}

x2 <- data.frame(v1=xbar2)

set.seed(3376)
min=-40; max=40; n=100
xbar3=rep(0,1000000)
for (i in 1:1000000) {xbar3[i]= mean(runif(n, min, max))}

x3 <- data.frame(v1=xbar3)

x <- list(v1=x1,v2=x2,v3=x3)
data <- melt(x)

# Figure 15-2
ggplot(data,aes(x=value, fill=L1)) +
  geom_density(alpha=.50) +
  ggtitle("Figure 15-2: Increased Draws, Increased Accuracy") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold"),
        legend.position = c(.8,.6)) +
  scale_fill_discrete(name = "Number of Observations",
                      labels = c("5", "25", "100"))

# Figure 15-3
happydf <- data.frame(id = 1:1000, x = rnorm(1000, 0, 1), e = rnorm(1000, 0, 3))
happydf$y <- 4.5*happydf$x + happydf$e

ggplot(happydf, aes(x, y)) +
  geom_smooth(method="lm", se=FALSE) +
  geom_point(col = "#bf0000", alpha = .4) +
             theme_minimal() +
               theme(plot.title = element_text(size = 8, face = "bold"),
                     axis.title = element_text(size = 8, face = "bold"),
                     legend.title = element_text(size = 10)) +
               ggtitle("Figure 15-3: The True Model") +
               ylab("y") +
               xlab("x")
# Figure 15-4
curveddf <- data.frame(id = 1:1000, x = rnorm(1000, 0, 1),
                       e = rnorm(1000, 0, 1))
curveddf$y <- exp(curveddf$x) + curveddf$e
curvedmodel.lm <- lm(y ~ x, data = curveddf)

ggplot(curveddf, aes(x, y)) +
  geom_smooth(method="lm", se=FALSE, col="#0000bf") +
              geom_point(col = "#bf0000", alpha = .2) +
                         theme_minimal() +
                           theme(plot.title = element_text(size = 8, face = "bold"),
                                 axis.title = element_text(size = 8, face = "bold"),
                                 legend.title = element_text(size = 10)) +
               ggtitle("Figure 15-4: Fitting a Straight Line to Curved Data") +
                           ylab("y") +
                           xlab("x")

# Figure 15-5
vardf <- data.frame(id = 1:1000, x = rnorm(1000, 0, 1),
                    e = rnorm(1000, 0, 3))
vardf$y <- 4.5*vardf$x + (1 + vardf$x / 2)*vardf$e
varmodel.lm <- lm(y ~ x, data = vardf)

ggplot(vardf, aes(x, y)) +
  geom_smooth(method="lm", se=FALSE, col="#0000bf") +
              geom_point(col = "#bf0000", alpha = .2) +
                         theme_minimal() +
                           theme(plot.title = element_text(size = 8, face = "bold"),
                                 axis.title = element_text(size = 8, face = "bold"),
                                 legend.title = element_text(size = 10)) +
              ggtitle("Figure 15-5: Regression With Nonconstant Variance") +
                           ylab("y") +
                           xlab("x")
# Code Chunk 15-8
p1 <- ggplot(states, aes(medinc, infant)) +
      geom_point(col="#bf0000") +
      theme_minimal() +
      geom_smooth(method="lm", se=FALSE, col="#0000bf") +
      geom_text_repel(size=2, data=states, aes(label=
                      ifelse(states$st %in% c("DE", "MS", "MD", "NM"),
                             as.character(states$st), "")),
                             hjust=-.5, vjust=0, show.legend=FALSE) +
      ylab("Number of Deaths per 1,000 Live Births") +
      xlab("Median Household Income") +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold"),
            axis.title = element_text(size = 8, face = "bold")) +
            annotate("segment", x = 54570, xend = 54570, y = 9,
                      yend = 6.5, size = .2, col="#bf0000", linetype = "dashed") +
            annotate("text", x = 60000, y = 8, parse = F,
            label = 'Residual for Delaware = 2.5', size = 2)

# Figure 15-6
model <- lm(infant ~ medinc, data=states)
states$infant.p <- predict(model)
states$infant.r <- resid(model)

p2 <- ggplot(states, aes(infant.p, infant.r)) +
      geom_point(col="#bf0000") +
      geom_smooth(method="lm", se=FALSE, col="#0000bf") +
      geom_smooth(col="grey", se=FALSE, linetype = "dashed") +
      geom_text_repel(size=2, data=states, aes(label=
                     ifelse(states$st %in% c("DE", "MS", "MD", "NM"),
                     as.character(states$st), "")),
                     hjust=-.5, vjust=0, show.legend=FALSE) +
      ylab("Residuals") +
      xlab("Fitted Values") +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold"),
            axis.title = element_text(size = 8, face = "bold")) +
      annotate("segment", x = 6.52, xend = 6.52, y = 0,
               yend = 2.5, size = .2, col="#bf0000", linetype = "dashed") +
      annotate("text", x = 5.9, y = 1.2, parse = F,
               label = 'Residual for Delaware = 2.5', size = 2)

grid.arrange(p1, p2, ncol=2, top=textGrob("Figure 15-6: Anatomy of a Residual Plot", gp=gpar(fontsize=8)))

# Code Chunk 15-10
happymodel.lm <- lm(y ~ x, data=happydf)

p1 <- ggplot(happydf, aes(x, y)) +
  geom_smooth(method="lm", se=FALSE) +
  geom_point(col = "#bf0000", alpha = .2) +
             theme_minimal() +
               theme(plot.title = element_text(size = 8, face = "bold"),
                     axis.title = element_text(size = 8, face = "bold"),
                     legend.title = element_text(size = 10)) +
               ggtitle("Regression Line") +
               ylab("y") +
               xlab("x")

# Figure 15-7
happydf$res <- resid(happymodel.lm)
happydf$pred <- predict(happymodel.lm)

p2 <- ggplot(happydf, aes(pred, res)) +
  geom_smooth(method="lm", se=FALSE, col="black",
              linetype = "dashed") +
  geom_point(col = "#bf0000", alpha = .2) +
             theme_minimal() +
               theme(plot.title = element_text(size = 8, face = "bold"),
                     axis.title = element_text(size = 8, face = "bold"),
                     legend.title = element_text(size = 10)) +
               ggtitle("Residual Plot") +
               ylab("y") +
               xlab("x")

grid.arrange(p1, p2, ncol=2, top=textGrob("Figure 15-7: Gauss-Markov Is Met",
                                        gp=gpar(fontsize=8)))

#Code Chunk 15-12
p1 <- ggplot(curveddf, aes(x, y)) +
  geom_smooth(method="lm", se=FALSE, col="#0000bf") +
              geom_point(col = "#bf0000", alpha = .1) +
                         theme_minimal() +
                           theme(plot.title = element_text(size = 8, face = "bold"),
                                 axis.title = element_text(size = 8, face = "bold"),
                                 legend.title = element_text(size = 10)) +
                           ggtitle("OLS Regression") +
                           ylab("y") +
                           xlab("x")

# Figure 15-8
curveddf$res <- resid(curvedmodel.lm)
curveddf$pred <- predict(curvedmodel.lm)

p2 <- ggplot(curveddf, aes(pred, res)) +
  geom_smooth(method="lm", se=FALSE, col="black", linetype = "dashed") +
  geom_point(col = "#bf0000", alpha = .1) +
             theme_minimal() +
               theme(plot.title = element_text(size = 8, face = "bold"),
                     axis.title = element_text(size = 8, face = "bold"),
                     legend.title = element_text(size = 10)) +
               ggtitle("Residual Plot") +
               ylab("y") +
               xlab("x")
             
grid.arrange(p1, p2, ncol=2, top=textGrob("Figure 15-8: Systematic Overprediction and Underprediction", gp=gpar(fontsize=8)))

# Code Chunk 15-14
df <- data.frame(id = 1:1000, x = rnorm(1000, 0, 1),
                 e = rnorm(1000, 0, 3))

df$y <- 4.5*df$x + (1 + df$x / 2)*df$e

model.lm <- lm(y ~ x, data = df)

p1 <- ggplot(df, aes(x, y)) +
              geom_smooth(method="lm", se=FALSE, col="#0000bf") +
              geom_point(col = "#bf0000", alpha = .2) +
              theme_minimal() +
              theme(plot.title = element_text(size = 8, face = "bold"),
              axis.title = element_text(size = 8, face = "bold"),
              legend.title = element_text(size = 10)) +
              ggtitle("Regression With Nonconstant Variance") +
              ylab("y") +
              xlab("x")

# Figure 15-9
df$res <- resid(model.lm)
df$pred <- predict(model.lm)

p2 <- ggplot(df, aes(pred, res)) +
      geom_smooth(method="lm", se=FALSE, col="black", linetype = "dashed") +
      geom_point(col = "#bf0000", alpha = .2) +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold"),
            axis.title = element_text(size = 8, face = "bold"),
            legend.title = element_text(size = 10)) +
      ggtitle("Residual Plot Shows Nonconstant Variance") +
      ylab("y") +
      xlab("x")
             
grid.arrange(p1, p2, ncol=2, top=textGrob("Figure 15-9: Nonconstant Variance in the Residuals", gp=gpar(fontsize=8)))


# Chapter 16: Diagnostics II: Residuals, Leverages, and Measures of Influence

# Figure 16-1
nstate <- states
row.names(nstate) <- nstate$st
model.lm <- lm(femleg ~ density + evangel + democrat + hsdiploma, data
               = nstate)
states$res <- resid(model.lm)
states$pred <- predict(model.lm)

ggplot(states, aes(pred, res)) +
      geom_point(col="#bf0000") +
      geom_text_repel(size=3.5, col = "black", aes(label=
                      ifelse(states$st %in% c("AZ", "PA", "ID", "SD"),
                      as.character(states$st), "")),
                      hjust=-.5, vjust=0, show.legend=FALSE) +
      geom_hline(yintercept = 0, linetype = 2) +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold"),
            axis.title = element_text(size = 8, face = "bold")) +
               xlab("Predicted or 'Fitted' Values") +
               ylab("Residuals") +
               ggtitle("Figure 16-1: A Formless Cloud")

# Figure 16-2
states$hat <- hatvalues(model.lm)

ggplot(states, aes(hat, res)) + 
  geom_point(col="#bf0000") +
  geom_text_repel(size=3.5, col = "black", data=states, aes(label=
                  ifelse(states$st %in% c("UT", "DE", "NJ", "RI"),
                  as.character(states$st), "")),
                  hjust=-.5, vjust=0, show.legend=FALSE) +
  geom_hline(yintercept = 0, linetype = 2) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  xlab("Leverages or 'Hat' Values") +
  ylab("Residuals") +
  ggtitle("Figure 16-2: Residuals Versus Leverages")

# Figure 16-3
leverage.lm <- lm(hsdiploma ~ medinc, data = states)
states$lev <- hatvalues(leverage.lm)

ggplot(states, aes(medinc, hsdiploma)) +
      geom_point(col="#bf0000") +
      geom_smooth(method="lm", col="#0000bf", size = .5, se=FALSE ) +
      geom_text_repel(size=3.5, col = "black", data=states, aes(label= ifelse(states$st %in% c("MD", "NY"), as.character(states$st), "")),
                     hjust=1.5, vjust=1.5, show.legend=FALSE) +
      geom_text(size=3.5, col = "#0000bf", data=states, aes(label=
                ifelse(states$st %in% c("MD", "NY"),
                round(states$lev, digits = 2), "")),
                hjust=1, vjust=-1, show.legend=FALSE) +
      xlab("Median Household Income") +
      ylab("Percentage of Population With High School Diploma") +
      ggtitle("Figure 16-3: Maryland Has Largest Value in x") +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold"),
            axis.title = element_text(size = 8, face = "bold"))

# Code Chunk 16-4
states$nmedinc <- ifelse(states$st=="MD", 20000 +
                           states$medinc, states$medinc)

states$nhsdiploma <- ifelse(states$st=="MD", 7 + states$hsdiploma,
                            states$hsdiploma)

xlev.lm <- lm(hsdiploma ~ nmedinc, data = states)
xylev.lm <- lm(nhsdiploma ~ nmedinc, data = states)
states$xlev <- hatvalues(xlev.lm)
states$xylev <- hatvalues(xylev.lm)

# Figure 16-4

p1 <- ggplot(states, aes(nmedinc, hsdiploma)) +
      geom_point(col="#bf0000") +
      geom_smooth(method="lm", col="#0000bf", size = .5, se=FALSE) + 
      geom_text(size=3.5, col = "black", data=states, aes(label=
                ifelse(states$st == "MD",
                as.character(states$st), "")),       
                hjust=1.5, vjust=1.5, show.legend=FALSE) +
      geom_text_repel(size=3.5, col = "#0000bf", data=states, aes(label=ifelse(states$st == "MD",
                      round(states$xlev, digits = 2), "")),
                      hjust=1, vjust=-1, show.legend=FALSE) +
      xlab("Median Household Income") +
      ylab("Percentage of Population With High School Diploma") +
      ggtitle("Panel A: Maryland’s Income Is Changed") +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold"),
            axis.title = element_text(size = 8, face = "bold"))
      
      
p2 <- ggplot(states, aes(nmedinc, nhsdiploma)) +
             geom_point(col="#bf0000") +
             geom_smooth(method="lm", col="#0000bf", size = .5, se=FALSE ) +
             geom_text(size=3.5, col = "black", data=states, aes(label=
                             ifelse(states$st == "MD",
                             as.character(states$st), "")),
                             hjust=1.5, vjust=1.5, show.legend=FALSE) +
             geom_text_repel(size=3.5, col = "#0000bf", data=states, aes(label=
                             ifelse(states$st == "MD",
                             round(states$xylev, digits = 2), "")),
                             hjust=1, vjust=-1, show.legend=FALSE) +
             xlab("Median Household Income") +
             ylab("Percentage of Population With High School Diploma") +
             ggtitle("Panel B: Education and Income Are Changed") +
             theme_minimal() +
             theme(plot.title = element_text(size = 8, face = "bold"),
                   axis.title = element_text(size = 8, face = "bold"))


grid.arrange(p1, p2, ncol=2, top=textGrob("Figure 16-4: Changing Value’s Impact on Leverage", gp=gpar(fontsize=8)))

# Figure 16-5
states$cook <- cooks.distance(model.lm)

ggplot(states, aes(hat, res)) +
      geom_point(aes(size = cook), col="#bf0000") +
      geom_text_repel(size=3.5, col = "black", data=states, aes(label=
                      ifelse(rank(-cook) < 5, st, NA)),
                      hjust= -3, vjust= 2, show.legend=FALSE) +
      geom_hline(yintercept = 0, linetype = 2) +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold"),
            axis.title = element_text(size = 8, face = "bold"),
            legend.title = element_text(size = 8, face = "bold")) +
      xlab("Leverages or 'Hat' Values") +
      ylab("Residuals") + 
      ggtitle("Figure 16-5: Previous Plot Sized by Cook's D") 

# Figure 16-6
nstate <- states
row.names(nstate) <- nstate$st


db_dfb(model.lm, "Figure 16-6: Dfbetas for Each Coefficient")
  
# Table 16-1
without.lm <- update(model.lm, data = subset(nstate, st!="UT"))

stargazer(model.lm, without.lm, header = FALSE, type = "text",
          title = "Table 16-1: Utah’s Important Impact on the Regression")

# Figure 16-7
db_avp(model.lm, "Figure 16-7: Added Variable Plots for 'model.lm'")


# Chapter 17: Logistic Regression

# Figure 17-1
ggplot(states, aes(log(medinc), stand)) +
      geom_point(col="#bf0000", cex=.7) +
      theme_minimal() +
      theme(plot.title = element_text(size = 8, face = "bold"),
            axis.title = element_text(size = 8, face = "bold")) +
      geom_smooth(method="lm", se=FALSE, col = "#0000bf") +
      geom_text_repel(size=3, aes(label = st, size = 1,
                      hjust = 0, vjust=-1),
                      col="grey") +
      ggtitle("Figure 17-1: More Income Lowers Defensiveness") +
      ylab("Stand Your Ground = 1") +
      xlab("Median Household Income")

# Table 17-1
badreg.lm <- lm(stand ~ medinc, data = states)
stargazer(badreg.lm, title = "Table 17-1: OLS Regression With Binary Dependent Variable",
          header = FALSE, type = "text")

# Figure 17-2
states$res <- resid(badreg.lm)
states$pred <- predict(badreg.lm)
ggplot(states, aes(pred, res)) + geom_point(col="#bf0000", cex=.7) +
        geom_hline(yintercept = 0, linetype = 2) +
        theme_minimal() +
        theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
        geom_text_repel(size=3,
                  aes(label = st, size = 1, hjust = 0, vjust=-1),
                  col="grey") +
        xlab("Predicted or 'Fitted' Values") +
        ylab("Residuals") +
        ggtitle("Figure 17-2: Residual Plot")

# Table 17-2
states$inc1000 <- states$medinc/1000
model.glm <- glm(trumpwin ~ inc1000, data=states,
                 family=binomial)

stargazer(model.glm, title = "Table 17-2: Logistic Regression of Trump Winning State", header = FALSE, type = "text")

# Figure 17-3
trump.glm <- glm(trumpwin ~ inc1000, data = states, family = binomial)

visreg(trump.glm, "inc1000", header = FALSE, scale = "response",
       band=FALSE, gg=TRUE) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  annotate("segment", x = 50, xend = 50, y = 0, yend = .66,
            col = "grey", linetype = "dashed") +
  annotate("segment", x = 40, xend = 50, y = .66, yend = .66,
            col = "grey", linetype = "dashed") +
  annotate("segment", x = 60, xend = 60, y = 0, yend = .15,
            col = "grey", linetype = "dashed") +
  annotate("segment", x = 40, xend = 60, y = .15, yend = .15,
            col = "grey", linetype = "dashed") +
  annotate("text", x = 38, y = .66, parse = F,
            label = '.66') +
  annotate("text", x = 38, y = .15, parse = F,
            label = '.15') +
  ggtitle("Figure 17-3: Trump’s Chances Decreased With Income")

# Figure 17-4
trump1.glm <- glm(trumpwin ~ inc1000 + density,
                  data = states, family = binomial)

visreg(trump1.glm, "inc1000", by="density", overlay = TRUE,
       band = FALSE, scale = "response", legend = TRUE, gg=TRUE) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold"),
        legend.title = element_text(size = 10, face = "bold"),
        legend.position = c(0.8, 0.6)) +
  annotate("segment", x = 38, xend = 50, y = .325, yend = .325, col =
              "grey", linetype = "dashed") +
  annotate("segment", x = 38, xend = 50, y = .795, yend = .795, col =
              "grey", linetype = "dashed") +
  annotate("text", x = 36, y = .795, parse = F,
            label = '.795') +
  annotate("text", x = 36, y = .325, parse = F,
            label = '.325') +
  annotate("segment", x = 50, xend = 50, y = 0, yend = .795,
            col = "grey", linetype = "dashed") +
  ggtitle("Figure 17-4: Trump’s Chances Decreased as Income Rose") +
  xlab("Median Household Income in Thousands") +
  ylab("Predicted Probability of Trump Winning State")


# Table 17-3
Obama.glm <- glm(obamawin ~ inc1000 + hsdiploma + density,
                 data = states, family = binomial)
stargazer(Obama.glm, title = "Table 17-3: Probability of Obama Winning the State (2012)", header = FALSE, type = "text")


# Figure 17-5
visreg(Obama.glm, "inc1000", by = "hsdiploma", overlay = TRUE,
       scale = "response", band = FALSE, gg=TRUE) +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold"),
        legend.title = element_text(size = 10, face = "bold"),
        legend.position = c(.8, .2)) +
  annotate("segment", x = 38, xend = 50, y = .245, yend = .245, col =
              "grey", linetype = "dashed") +
  annotate("segment", x = 38, xend = 50, y = .69, yend = .69, col =
              "grey", linetype = "dashed") +
  annotate("text", x = 36, y = .69, parse = F, label = '.690') +
  annotate("text", x = 36, y = .245, parse = F, label = '.245') +
  annotate("segment", x = 50, xend = 50, y = 0, yend = .70, col =
              "grey", linetype = "dashed") +
  ggtitle("Figure 17-5: Obama’s Chances Increased as Income Rose") +
  xlab("Median Household Income in Thousands") +
  ylab("Predicted Probability of Obama Winning State")


# Tables 17-4 and 17-5
model1.glm <- glm(obamawin ~ inc1000, data = states, family = binomial)
model2.glm <- glm(obamawin ~ inc1000 + hsdiploma, data = states,
                  family = binomial)

object <- logitR2(model1.glm)
object1 <- logitR2(model2.glm)

## Table 17-4
knitr::kable(object, format = "pandoc",
             caption = "Table 17-4: Measures of Fit for Logit Model 1", digits = 4)
## Table 17-5
knitr::kable(object1, format = "pandoc",
             caption = "Table 17-5: Measures of Fit for Logit Model 2", digits = 4)

# Code Chunk 17-10
pchisqC(model1.glm$dev, model2.glm$dev, 1)
## [1] "0.863444"

# Code Chunk 17-11
mtest.glm <- glm(obamawin ~ inc1000, data = states, family = binomial)
states$pred.glm <- predict(mtest.glm, type = "response")
testwin <- states %>% dplyr::filter(obamawin == 1) %>%
  dplyr::select(pred.glm)
testlost <- states %>% dplyr::filter(obamawin == 0) %>%
  dplyr::select(pred.glm)
varlist <- list(testwin, testlost)
newvar <- melt(varlist)
newvar$L1 <- as.factor(newvar$L1)

# Figure 17-6
ggplot(newvar,aes(x=value, fill=L1)) +
  geom_density(alpha = .7) +
  ggtitle("Figure 17-6: Predicted Probability That Obama Won, Colored by Actual Wins/Losses") +
  theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold"),
        legend.position = "bottom",
        legend.background = element_rect(fill="white", size=0.5, linetype="solid")) +
  scale_fill_manual(values = c("#0000bf", "#bf0000"), name = "",
                                labels = c("States Actually Won",
                                            "States Actually Lost")) +
                      xlab("Predicted Probability of Obama Winning the State") +
                      ylab("Density") +
                      geom_vline(xintercept = .50, linetype = "dashed") +
                      geom_vline(xintercept = .25, linetype = "dashed") +
                      geom_vline(xintercept = .75, linetype = "dashed")
# Code Chunk 17-13
d_fun <- ecdf(testwin$pred.glm)
x0 <- .25
d_fun(x0)
1 - d_fun(x0)

d_fun <- ecdf(testlost$pred.glm)
x0 <- .25
d_fun(x0)

# Figure 17-7

roc.list <- roc(obamawin ~ inc1000, data = states)
g.list <- pROC::ggroc(roc.list)

g.list + theme_minimal() +
  theme(plot.title = element_text(size = 8, face = "bold"),
        axis.title = element_text(size = 8, face = "bold")) +
  geom_segment(aes(x = 1, xend = 0, y = 0, yend = 1),
               color="grey", linetype="dashed") +
  geom_point(aes(.40, .961), col = "#bf0000") +
             geom_point(aes(.7826, .8148), col = "#bf0000") +
                        geom_point(aes(.8260, .4444), col = "#bf0000") +
                        annotate("text", x = .6, y = .6, label = "AUC = 0.839") +
                        annotate("text", x = .38, y = .93, label = "0.25", col = "#bf0000") +
                        annotate("text", x = .75, y = .81, label = "0.50", col = "#bf0000") +
                        annotate("text", x = .79, y = .44, label = "0.75", col = "#bf0000") + 
  ggtitle("Figure 17-7: ROC Curve for Income")


# Figure 17-8
roc.list <- roc(obamawin ~ inc1000 + hsdiploma + density,
                data = states)
g.list <- pROC::ggroc(roc.list)

g.list +
  theme_minimal() +
  theme(plot.title = element_text(size = 10, face = "bold"),
        axis.title = element_text(size = 10, face = "bold"),
        legend.title = element_text(size = 10, face = "bold"),
        legend.position = c(.8, .2),
        legend.background = element_rect(fill="white", size=0.5, linetype="solid", colour ="white")) +
  geom_segment(aes(x = 1, xend = 0, y = 0, yend = 1),
               color="grey", linetype="dashed") +
  ggtitle("Figure 17-8: ROC Curves for inc100, hsdiploma, and density")


# Practice on Analysis and Visualization

# 5 
death.glm <- glm(death ~ stuspend + murderrate + inc + democrat,
                 data=states, family=binomial)

visreg(death.glm, "murderrate", by="stuspend", overlay=TRUE, band=FALSE,
       scale = "response", gg=TRUE) +
      theme_minimal() + 
      theme(plot.title = element_text(size = 10, face = "bold"),
            axis.title = element_text(size = 10, face = "bold"),
            legend.title = element_text(size = 10, face = "bold"),
            legend.position = c(.8, .2),
            legend.background = element_rect(fill="white", size=0.5, linetype="solid", colour ="white")) 

# 6 
logitR2(death.glm)

# 7 
modelq7.glm <- glm(death ~ stuspend + murderrate + inc, data=states, family=
                     binomial)
modelq7a.glm <- glm(death ~ stuspend + murderrate + inc + democrat,
                    data=states, family=binomial)
object <- logitR2(modelq7.glm)
object1 <- logitR2(modelq7a.glm)
pchisqC(modelq7.glm$dev, modelq7a.glm$dev, 1)

## [1] "0.086357"

# 9 
roc.list <- roc(death ~ stuspend, data = states)
auc(roc.list)

# 10 
aucinc <- roc(death ~ inc, data = states)
auc(aucinc)

